%define anolis_release 7

%global __requires_exclude pkg-config
%global pkgdir %{_prefix}/lib/systemd
%global system_unit_dir %{pkgdir}/system
%global user_unit_dir %{pkgdir}/user
%global journal_remote_units_restart systemd-journal-gatewayd.service systemd-journal-remote.service systemd-journal-upload.service
%global journal_remote_units_norestart systemd-journal-gatewayd.socket systemd-journal-remote.socket
%global systemd_etc_dir /etc/systemd/system
%global systemd_local_dir /var/lib/systemd

%bcond_without gnu_efi
%bcond_without bpf
%bcond_with    bootstrap
%bcond_without tests
%bcond_without lto
%bcond_with    inplace

%if %{without lto}
%global _lto_cflags %nil
%endif

%global udev_services systemd-udev{d,-settle,-trigger}.service systemd-udevd-{control,kernel}.socket systemd-timesyncd.service %{with gnu_efi:systemd-boot-update.service}

Name: systemd
Url: https://www.freedesktop.org/wiki/Software/systemd
Version: 252.4
Release: %{anolis_release}%{?dist}
License: LGPLv2+ and MIT and GPLv2+
Summary: System and Service Manager
Source0: https://github.com/systemd/systemd-stable/archive/refs/tags/v%{version}.tar.gz

Source1: triggers.systemd
Source2: purge-nobody-user
Source3: yum-protect-systemd.conf
Source4: inittab
Source5: sysctl.conf.README
Source6: systemd-journal-remote.xml
Source7: systemd-journal-gatewayd.xml
Source8: 20-yama-ptrace.conf
Source9: systemd-udev-trigger-no-reload.conf
Source10: libsystemd-shared.abignore
Source11: 10-oomd-defaults.conf
Source12: 10-oomd-per-slice-defaults.conf

Source21: macros.sysusers
Source22: sysusers.attr
Source23: sysusers.prov
Source24: sysusers.generate-pre.sh

Source31: systemd-tests-file-list
Source32: systemd-devel-file-list

Patch0000: systemd-timesyncd-default-to-aliyun.patch
Patch0001: 0001-pam-align-second-and-third-columns.patch
Patch0002: 0002-pam-add-a-call-to-pam_namespace.patch
Patch0003: 0003-pam-actually-align-the-columns.patch
Patch0004: 0004-test.patch

Patch0201: use-bfq-scheduler.patch
Patch0202: fedora-use-system-auth-in-pam-systemd-user.patch
 
BuildRequires: gcc gcc-c++ clang coreutils
BuildRequires: libcap-devel libmount-devel libfdisk-devel libpwquality-devel
BuildRequires: pam-devel libselinux-devel audit-libs-devel dbus-devel
%if %{without bootstrap}
BuildRequires: cryptsetup-devel
%endif
BuildRequires: /usr/sbin/sfdisk /usr/bin/getfacl
BuildRequires: libacl-devel gobject-introspection-devel libblkid-devel
BuildRequires: xz-devel xz lz4-devel lz4 bzip2-devel libzstd-devel
BuildRequires: libidn2-devel libcurl-devel kmod-devel elfutils-devel
BuildRequires: openssl-devel gnutls-devel qrencode-devel libmicrohttpd-devel
BuildRequires: libxkbcommon-devel iptables-devel
BuildRequires: pkgconfig(libfido2) pkgconfig(libbpf)
BuildRequires: pkgconfig(tss2-esys) pkgconfig(tss2-rc) pkgconfig(tss2-mu) 
BuildRequires: systemtap-sdt-devel libseccomp-devel
BuildRequires: libxslt docbook-style-xsl pkgconfig gperf gawk tree hostname
BuildRequires: python3dist(lxml) python3dist(jinja2)
BuildRequires: firewalld-filesystem
%if %{with gnu_efi}
BuildRequires: gnu-efi gnu-efi-devel
%endif
BuildRequires: meson >= 0.43 gettext valgrind-devel pkgconfig(bash-completion)
BuildRequires: perl perl(IPC::SysV)

%if %{with bpf}
BuildRequires: bpftool
%endif

Requires(post): coreutils grep openssl-libs
Requires: dbus >= 1.9.18
Requires: systemd-pam = %{EVR}
Requires: (systemd-rpm-macros = %{EVR} if rpm-build)
Requires: systemd-libs = %{EVR}
Requires: (util-linux-core or util-linux)
Recommends: systemd-networkd = %{EVR}
Recommends: systemd-resolved = %{EVR}
Recommends: diffutils libxkbcommon
Provides:  /bin/systemctl /sbin/shutdown syslog
Provides:  systemd-units = %{EVR}
Obsoletes: system-setup-keyboard < 0.9
Provides:  system-setup-keyboard = 0.9
Obsoletes: systemd-sysv < 206
Obsoletes: systemd < 249~~
Provides:  systemd-sysv = 206
Conflicts: initscripts < 9.56.1
Obsoletes: timedatex < 0.6-3
Provides:  timedatex = 0.6-3
Conflicts: systemd-standalone-tmpfiles < %{EVR}^
Conflicts: systemd-standalone-sysusers < %{EVR}^
Provides:  systemd-tmpfiles = %{EVR}
Obsoletes: systemd-tmpfiles < %{EVR}
Provides:  systemd-sysusers = %{EVR}
Obsoletes: systemd-tmpfiles < %{EVR}

Recommends: libidn2.so.0()(64bit) ibidn2.so.0(IDN2_0.0.0)(64bit) 
Recommends: libpcre2-8.so.0()(64bit)
Recommends: libpwquality.so.1()(64bit) libpwquality.so.1(LIBPWQUALITY_1.0)(64bit)
Recommends: libqrencode.so.4()(64bit)
Recommends: libbpf.so.0()(64bit) libbpf.so.0(LIBBPF_0.4.0)(64bit)
Recommends: libdw.so.1()(64bit) libdw.so.1(ELFUTILS_0.186)(64bit)
Recommends: libelf.so.1()(64bit) libelf.so.1(ELFUTILS_1.7)(64bit)
Recommends: libcryptsetup.so.12()(64bit) libcryptsetup.so.12(CRYPTSETUP_2.4)(64bit)

%description
systemd is a suite of basic building blocks for a Linux system.
It provides a system and service manager that runs as PID 1
and starts the rest of the system.

systemd provides aggressive parallelization capabilities,
uses socket and D-Bus activation for starting services,
offers on-demand starting of daemons,
keeps track of processes using Linux control groups,
maintains mount and automount points,
and implements an elaborate transactional dependency-based service control logic.
systemd supports SysV and LSB init scripts and works as a replacement for sysvinit.

%package libs
Summary:   systemd libraries
License:   LGPLv2+ and MIT
Provides:  nss-myhostname = 0.4
Obsoletes: nss-myhostname < 0.4
Obsoletes: libudev < 183
Obsoletes: systemd < 185
Obsoletes: systemd-compat-libs < 230
Conflicts: systemd < 185

%description libs
This package contains libraries for systemd and udev.

%package pam
Summary:  systemd PAM module
Requires: systemd = %{EVR}

%description pam
Systemd PAM module registers the session with systemd-logind.

%package rpm-macros
Summary:   Macros that define paths and scriptlets related to systemd
BuildArch: noarch

%description rpm-macros
Macros that define paths and scriptlets related to systemd

%package devel
Summary:   Development headers for systemd
License:   LGPLv2+ and MIT
Requires:  systemd-libs = %{EVR}
Requires:  (systemd-rpm-macros = %{EVR} if rpm-build)
Provides:  libudev-devel = %{version}
Obsoletes: libudev-devel < 183

%description devel
This package contains development headers and auxiliary files
for developing applications linking to libudev or libsystemd.

%package udev
Summary: Rule-based device node and kernel event manager
License:   LGPLv2+

Requires:  systemd = %{EVR}
Requires:  kmod >= 18 kbd
Provides:  udev = %{version}
Obsoletes: udev < 183 systemd < 245.6
Requires(post):   grep
%{?systemd_requires}

Recommends: libcryptsetup.so.12()(64bit) libcryptsetup.so.12(CRYPTSETUP_2.4)(64bit)
Recommends: libdw.so.1()(64bit) libdw.so.1(ELFUTILS_0.186)(64bit)
Recommends: libelf.so.1()(64bit) libelf.so.1(ELFUTILS_1.7)(64bit)
Recommends: libfido2.so.1()(64bit)
Recommends: libtss2-esys.so.0()(64bit) libtss2-mu.so.0()(64bit) libtss2-rc.so.0()(64bit)

Suggests:  systemd-bootchart
Provides:  u2f-hidraw-policy = 1.0.2-40
Obsoletes: u2f-hidraw-policy < 1.0.2-40
Obsoletes: systemd-udev < 252.2^

%description udev
This package contains systemd-udev and the rules and hardware database
needed to manage device nodes.
This package is necessary on physical machines and in virtual machines,
but not in containers.
This package also provides systemd-timesyncd,a network time protocol daemon.
It also contains tools to manage encrypted home areas
and secrets bound to the machine,
and to create or grow partitions and make file systems automatically.

%package container
Summary: Tools for containers and VMs
License:   LGPLv2+
Requires:  systemd = %{EVR}
Suggests:  libcurl-minimal
Obsoletes: systemd < 229
%{?systemd_requires}

%description container
Systemd tools to spawn and manage containers and virtual machines.
This package contains systemd-nspawn, machinectl, systemd-machined,
and systemd-importd.

%package journal-remote
Summary:   Tools to send journal events over the network
Requires:  systemd = %{EVR}
License:   LGPLv2+
Requires:  firewalld-filesystem
Provides:  systemd-journal-gateway = %{EVR}
Obsoletes: systemd-journal-gateway < 227
Suggests:  libcurl-minimal

%description journal-remote
Programs to forward journal entries over the network, using encrypted HTTP,
and to write journal files from serialized journal contents.

This package contains systemd-journal-gatewayd, systemd-journal-remote,
and systemd-journal-upload.

%package networkd
Summary:   System daemon that manages network configurations
Requires:  systemd = %{EVR}
License:   LGPLv2+
Obsoletes: systemd < 246.6

%description networkd
systemd-networkd is a system service that manages networks.
It detects and configures network devices as they appear,
as well as creating virtual network devices.

%package resolved
Summary:   Network Name Resolution manager
Requires:  systemd = %{EVR}
Obsoletes: systemd < 249~~
Requires:  libidn2.so.0()(64bit) libidn2.so.0(IDN2_0.0.0)(64bit)
Requires(posttrans): grep

%description resolved
systemd-resolved is a system service that provides network name resolution
to local applications. 
It implements a caching and validating DNS/DNSSEC stub resolver,
as well as an LLMNR and MulticastDNS resolver and responder.

%package oomd-defaults
Summary:   Configuration files for systemd-oomd
Requires:  systemd = %{EVR}
License:   LGPLv2+
BuildArch: noarch

%description oomd-defaults
This package contains a set of drop-in files for systemd units
to enable action from systemd-oomd, a userspace out-of-memory (OOM) killer.

%package standalone-tmpfiles
Summary:   Standalone tmpfiles binary for use in non-systemd systems
Provides:  systemd-tmpfiles = %{EVR}
Obsoletes: systemd-tmpfiles < %{EVR}
RemovePathPostfixes: .standalone

%description standalone-tmpfiles
Standalone tmpfiles binary with no dependencies on the systemd-shared library or
other libraries from systemd-libs.
This package conflicts with the main systemd package
and is meant for use in non-systemd systems.

%package standalone-sysusers
Summary:   Standalone sysusers binary for use in non-systemd systems
Provides:  systemd-sysusers = %{EVR}
Obsoletes: systemd-sysusers < %{EVR}
RemovePathPostfixes: .standalone

%description standalone-sysusers
Standalone sysusers binary with no dependencies on the systemd-shared library
or other libraries from systemd-libs.
This package conflicts with the main systemd package
and is meant for use in non-systemd systems.

%if %{with gnu_efi}
%package boot-unsigned
Summary: UEFI boot manager (unsigned version)
Provides: systemd-boot-unsigned-%{efi_arch} = %{EVR}
Provides: systemd-boot = %{EVR}
Obsoletes: systemd-udev < 252.2^

%description boot-unsigned
systemd-boot (short: sd-boot) is a simple UEFI boot manager.
It provides a graphical menu to select the entry to boot
and an editor for the kernel command line.
systemd-boot supports systems with UEFI firmware only.
This package contains the unsigned version.
Install systemd-boot instead to get the version that works with Secure Boot.
%endif

%package tests
Summary:  Internal unit tests for systemd
Requires: systemd = %{EVR}
License:  LGPLv2+

%description tests
"Installed tests" that are usually run as part of the build system.
They can be useful to test systemd internals.

%package doc
Summary:   Documentation files for %{name}
Requires:  systemd = %{EVR}
BuildArch: noarch

%description    doc
The %{name}-doc package contains documentation files for %{name}.

%prep
%autosetup -n %{name}-stable-%{version} -p1

%build
CONFIGURE_OPTS=(
        -Dmode=release
        -Dsysvinit-path=/etc/rc.d/init.d -Drc-local=/etc/rc.d/rc.local
        -Dntp-servers='ntp.aliyun.com 0.cn.pool.ntp.org 1.cn.pool.ntp.org 2.cn.pool.ntp.org 3.cn.pool.ntp.org'
        -Dapparmor=false -Dblkid=true -Ddns-servers= -Dfdisk=true -Dima=true -Ddev-kvm-mode=0666
        -Duser-path=/usr/local/bin:/usr/local/sbin:/usr/bin:/usr/sbin
        -Dservice-watchdog=
        -Dkmod=true -Dxkbcommon=true
        -Dseccomp=true -Dselinux=true -Dpam=true -Dacl=true
        -Dbpf-framework=%[%{with bpf}?"true":"false"]
        -Dpolkit=true -Dsmack=true
        -Dxz=true -Dzlib=true -Dbzip2=true -Dlz4=true -Dzstd=true
        -Dopenssl=true -Dcryptolib=openssl -Dp11kit=true -Dgcrypt=false -Daudit=true
        -Delfutils=true -Defi=true
        -Dlibcryptsetup=%[%{with bootstrap}?"false":"true"]
        -Dpwquality=true -Dqrencode=true -Dgnutls=true -Dmicrohttpd=true
        -Dlibidn2=true -Dlibiptc=false -Dlibcurl=true -Dlibfido2=true
        -Dgnu-efi=%[%{with gnu_efi}?"true":"false"]
        -Dtpm=true -Dtpm2=true -Dhwdb=true
        -Dsysusers=true -Dstandalone-binaries=true
        -Ddefault-kill-user-processes=false
        -Dfirst-boot-full-preset=true
        -Dtests=unsafe -Dinstall-tests=true
        -Dtty-gid=5 -Dusers-gid=100
        -Dnobody-user=nobody -Dnobody-group=nobody
        -Dcompat-mutable-uid-boundaries=true
        -Dsplit-usr=false -Dsplit-bin=true
        -Db_lto=%[%{with lto}?"true":"false"]
        -Db_ndebug=false -Dman=true
        -Dversion-tag=v%{EVR} -Dshared-lib-tag=%{EVR}
        -Dfallback-hostname=%[0%{?anolis}?"anolis":"localhost"]
        -Ddefault-dnssec=no -Ddefault-dns-over-tls=no
        -Ddefault-mdns=no -Ddefault-llmnr=resolve
        -Dstatus-unit-format-default=combined
        -Doomd=true -Dadm-gid=4 -Daudio-gid=63 -Dcdrom-gid=11
        -Ddialout-gid=18 -Ddisk-gid=6 -Dinput-gid=104 -Dkmem-gid=9
        -Dkvm-gid=36 -Dlp-gid=7 -Drender-gid=105 -Dsgx-gid=106
        -Dtape-gid=33 -Dtty-gid=5 -Dusers-gid=100 -Dutmp-gid=22
        -Dvideo-gid=39 -Dwheel-gid=10
        -Dsystemd-journal-gid=190 -Dsystemd-network-uid=192 -Dsystemd-resolve-uid=193
)

%if %{with inplace}
  command -v ccache 2>/dev/null && { CC="${CC:-ccache %__cc}"; CXX="${CXX:-ccache %__cxx}"; }
  [ -e %{_vpath_builddir}/build.ninja ] && %__meson configure %{_vpath_builddir} "${CONFIGURE_OPTS[@]}" ||
%endif

{ %meson "${CONFIGURE_OPTS[@]}"; }
%meson_build

triggers_new=%{_vpath_builddir}/src/rpm/triggers.systemd.sh
if ! diff -u %{SOURCE1} ${triggers_new}; then
   echo -e "\n\n\nWARNING: triggers.systemd in Source1 is different!"
   echo -e "      cp $PWD/${triggers_new} %{SOURCE1}\n\n\n"
   sleep 5
fi

%install
%meson_install

install -d %{buildroot}/%{_sbindir}
ln -sf ../bin/udevadm %{buildroot}%{_sbindir}/udevadm

touch %{buildroot}/etc/crypttab
chmod 600 %{buildroot}/etc/crypttab

install -m 0644 -D -t %{buildroot}/etc/ %{SOURCE4}
install -m 0644 -D %{SOURCE5} %{buildroot}/etc/sysctl.conf
ln -s ../sysctl.conf %{buildroot}/etc/sysctl.d/99-sysctl.conf

install -d %{buildroot}%{system_unit_dir}/basic.target.wants
install -d %{buildroot}%{system_unit_dir}/default.target.wants
install -d %{buildroot}%{system_unit_dir}/dbus.target.wants
install -d %{buildroot}%{system_unit_dir}/syslog.target.wants
install -d %{buildroot}/run
install -d %{buildroot}/var/log
touch %{buildroot}/var/log/lastlog
chmod 0664 %{buildroot}/var/log/lastlog
touch %{buildroot}/run/utmp
touch %{buildroot}/var/log/{w,b}tmp

install -d %{buildroot}%{pkgdir}/system-generators
install -d %{buildroot}%{pkgdir}/user-generators

touch %{buildroot}%{_sysconfdir}/{hostname,vconsole.conf,vconsole.conf,machine-id,machine-info,localtime}
install -d %{buildroot}%{_sysconfdir}/X11/xorg.conf.d
touch %{buildroot}%{_sysconfdir}/X11/xorg.conf.d/00-keyboard.conf
install -d %{buildroot}%{pkgdir}/system-shutdown/
install -d %{buildroot}%{pkgdir}/system-sleep/
install -d %{buildroot}%{systemd_local_dir}/coredump
install -d %{buildroot}%{systemd_local_dir}/catalog
install -d %{buildroot}%{systemd_local_dir}/backlight
install -d %{buildroot}%{systemd_local_dir}/rfkill
install -d %{buildroot}%{systemd_local_dir}/linger
install -d %{buildroot}/var/lib/private
install -d %{buildroot}/var/log/private
install -d %{buildroot}/var/cache/private
install -d %{buildroot}/var/lib/private/systemd/journal-upload
install -d %{buildroot}%{systemd_local_dir}/timesync
ln -s ../private/systemd/journal-upload %{buildroot}%{systemd_local_dir}/journal-upload
install -d %{buildroot}/var/log/journal
touch %{buildroot}%{systemd_local_dir}/catalog/database
touch %{buildroot}/etc/udev/hwdb.bin
touch %{buildroot}%{systemd_local_dir}/random-seed
touch %{buildroot}%{systemd_local_dir}/timesync/clock
touch %{buildroot}/var/lib/private/systemd/journal-upload/state

install -m 0644 -D %{SOURCE3} %{buildroot}/etc/dnf/protected.d/systemd.conf
install -m 0644 -D -t %{buildroot}/usr/lib/firewalld/services/ %{SOURCE6} %{SOURCE7}

install -d %{buildroot}%{_pkgdocdir}
install -m 0644 -D -t %{buildroot}%{_pkgdocdir} %{SOURCE8}
install -m 0644 -D -t %{buildroot}%{system_unit_dir}/systemd-udev-trigger.service.d/ %{SOURCE9}
install -m 0644 -D -t %{buildroot}%{_prefix}/lib/systemd/ %{SOURCE10}
install -D -t %{buildroot}/usr/lib/systemd/ %{SOURCE2}
install -m 0644 -D -t %{buildroot}%{_prefix}/lib/systemd/oomd.conf.d/ %{SOURCE11}
install -m 0644 -D -t %{buildroot}%{system_unit_dir}/user-.slice.d/ %{SOURCE12}
install -m 0644 -D -t %{buildroot}%{system_unit_dir}/system.slice.d/ %{SOURCE12}
install -m 0644 -D -t %{buildroot}%{user_unit_dir}/slice.d/ %{SOURCE12}
install -m 0644 -D -t %{buildroot}%{_rpmconfigdir}/macros.d/ %{SOURCE21}
install -m 0644 -D -t %{buildroot}%{_rpmconfigdir}/fileattrs/ %{SOURCE22}
install -m 0755 -D -t %{buildroot}%{_rpmconfigdir}/ %{SOURCE23}
install -m 0755 -D -t %{buildroot}%{_rpmconfigdir}/ %{SOURCE24}

sed -i 's|#!/usr/bin/env python3|#!%{__python3}|' %{buildroot}/usr/lib/systemd/tests/run-unit-tests.py

%find_lang %{name}

%check
%if %{with tests}
meson test -C %{_vpath_builddir} -t 6 --print-errorlogs
%endif

%include %{SOURCE1}

%post
systemd-machine-id-setup &>/dev/null || :
oomd_status=$(systemctl is-active systemd-oomd 2>/dev/null || :)

if [ "$oomd_status" == "active" ]; then
    systemctl stop -q systemd-oomd 2>/dev/null || :
fi

systemctl daemon-reexec &>/dev/null || {
  if [ $1 -gt 1 ] && [ -d /run/systemd/system ] ; then
      kill -TERM 1 &>/dev/null || :
  fi
}

if [ "$oomd_status" == "active" ]; then
    systemctl start -q systemd-oomd 2>/dev/null || :
fi

[ $1 -eq 1 ] || exit 0

[ -w /var ] && mkdir -p /var/log/journal
[ -w /var ] && journalctl --update-catalog || :
systemd-sysusers || :
systemd-tmpfiles --create &>/dev/null || :

systemctl preset-all &>/dev/null || :
systemctl --global preset-all &>/dev/null || :

%postun
if [ $1 -eq 1 ]; then
    [ -w /var ] && journalctl --update-catalog || :
    systemd-tmpfiles --create &>/dev/null || :
fi

%systemd_postun_with_restart systemd-timedated.service systemd-portabled.service
%systemd_postun_with_restart systemd-homed.service systemd-hostnamed.service
%systemd_postun_with_restart systemd-journald.service systemd-localed.service
%systemd_postun_with_restart systemd-userdbd.service systemd-oomd.service

%triggerun resolved -- systemd < 246.1
systemctl --no-reload preset systemd-resolved.service &>/dev/null || :

if systemctl -q is-enabled systemd-resolved.service &>/dev/null; then
    systemctl -q is-enabled NetworkManager.service 2>/dev/null && \
    ! test -L /etc/resolv.conf 2>/dev/null && \
    ! mountpoint /etc/resolv.conf &>/dev/null && \
    grep -q 'Generated by NetworkManager' /etc/resolv.conf 2>/dev/null && \
    echo -e '/etc/resolv.conf was generated by NetworkManager.\nRemoving it to let systemd-resolved manage this file.' && \
    mv -v /etc/resolv.conf /etc/resolv.conf.orig-with-nm && \
    ln -sv ../run/systemd/resolve/stub-resolv.conf /etc/resolv.conf 2>/dev/null || :

    systemctl start systemd-resolved.service &>/dev/null || :
fi

%triggerpostun -- systemd < 247.3
systemctl --no-reload preset systemd-oomd.service &>/dev/null || :

%post udev
mv /var/lib/random-seed %{systemd_local_dir}/random-seed &>/dev/null
mv /var/lib/backlight %{systemd_local_dir}/backlight &>/dev/null
if [ -L %{systemd_local_dir}/timesync ]; then
    rm %{systemd_local_dir}/timesync
    mv /var/lib/private/systemd/timesync %{systemd_local_dir}/timesync
fi
if [ -f %{systemd_local_dir}/clock ] ; then
    mkdir -p %{systemd_local_dir}/timesync
    mv %{systemd_local_dir}/clock %{systemd_local_dir}/timesync/.
fi

udevadm hwdb --update &>/dev/null
%systemd_post %udev_services

/usr/lib/systemd/systemd-random-seed save 2>&1 | grep -v 'Failed to open /dev/urandom' || :

grep -q -E '^KEYMAP="?fi-latin[19]"?' /etc/vconsole.conf 2>/dev/null &&
    sed -i.rpm.bak -r 's/^KEYMAP="?fi-latin[19]"?/KEYMAP="fi"/' /etc/vconsole.conf || :

%preun udev
%systemd_preun %udev_services

%postun udev
%systemd_postun_with_restart systemd-udevd.service systemd-timesyncd.service


%post journal-remote
%systemd_post %journal_remote_units_restart %journal_remote_units_norestart
%firewalld_reload

%preun journal-remote
%systemd_preun %journal_remote_units_restart %journal_remote_units_norestart
if [ $1 -eq 1 ] ; then
    if [ -f %{systemd_local_dir}/journal-upload/state -a ! -L %{systemd_local_dir}/journal-upload ] ; then
        mkdir -p /var/lib/private/systemd/journal-upload
        mv %{systemd_local_dir}/journal-upload/state /var/lib/private/systemd/journal-upload/.
        rmdir %{systemd_local_dir}/journal-upload || :
    fi
fi

%postun journal-remote
%systemd_postun_with_restart %journal_remote_units_restart
%firewalld_reload

%post networkd
if [ $1 -eq 1 ] && ls /usr/lib/systemd/libsystemd-shared-24[0-6].so &>/dev/null; then
    echo "Skipping presets for systemd-networkd.service, seems we are upgrading from old systemd."
else
    %systemd_post systemd-networkd.service systemd-networkd-wait-online.service
fi

%preun networkd
%systemd_preun systemd-networkd.service systemd-networkd-wait-online.service

%preun resolved
if [ $1 -eq 0 ] ; then
    systemctl disable --quiet systemd-resolved.service >/dev/null || :
    if [ -L /etc/resolv.conf ] && realpath /etc/resolv.conf | grep ^/run/systemd/resolve/; then
        rm -f /etc/resolv.conf
        [ -f /run/NetworkManager/resolv.conf ] && \
        systemctl -q is-enabled NetworkManager.service &>/dev/null && \
        ln -fsv ../run/NetworkManager/resolv.conf /etc/resolv.conf
    fi
fi

%post resolved
[ $1 -eq 1 ] || exit 0

touch /var/lib/rpm-state/systemd-resolved.initial-installation

if ls /usr/lib/systemd/libsystemd-shared-24[0-8].so &>/dev/null; then
    echo "Skipping presets for systemd-resolved.service, seems we are upgrading from old systemd."
    exit 0
fi

%systemd_post systemd-resolved.service

%posttrans resolved
[ -e /var/lib/rpm-state/systemd-resolved.initial-installation ] || exit 0
rm /var/lib/rpm-state/systemd-resolved.initial-installation
if systemctl -q is-enabled systemd-resolved.service &>/dev/null &&
    ! systemd-analyze cat-config systemd/resolved.conf 2>/dev/null |
        grep -iqE '^DNSStubListener\s*=\s*(no?|false|0|off)\s*$'; then

    if ! test -e /etc/resolv.conf && ! test -L /etc/resolv.conf; then
        ln -sv ../run/systemd/resolve/stub-resolv.conf /etc/resolv.conf || :
    elif test -d /run/systemd/system/ && ! mountpoint /etc/resolv.conf &>/dev/null; then
        ln -fsv ../run/systemd/resolve/stub-resolv.conf /etc/resolv.conf || :
    fi
fi

%files -f %{name}.lang
%ghost %attr(0664,root,root) %verify(not group) /run/utmp
%ghost %attr(0700,root,root) %dir /var/cache/private
%dir /var/lib/systemd
%ghost %attr(0700,root,root) %dir /var/lib/private
%ghost %dir /var/lib/private/systemd
%dir /var/lib/systemd/catalog
%ghost %dir /var/lib/systemd/linger
%ghost /var/lib/systemd/catalog/database
%ghost %dir %verify(not mode group) /var/log/journal
%ghost %attr(0664,root,root) %verify(not md5 size mtime group) /var/log/lastlog
%ghost %attr(0664,root,root) %verify(not group) /var/log/wtmp
%ghost %attr(0660,root,root) %verify(not group) /var/log/btmp
%ghost %attr(0700,root,root) %dir /var/log/private
%dir /etc/systemd
%dir /etc/rc.d
%dir /etc/tmpfiles.d
/etc/inittab
%ghost %config(noreplace) /etc/hostname
%ghost %attr(0444,root,root) %config(noreplace) /etc/machine-id
%ghost %config(noreplace) /etc/machine-info
%ghost %config(noreplace) /etc/localtime
%config(noreplace) /etc/dnf/protected.d/systemd.conf
%dir /etc/xdg/systemd
%config(noreplace) /etc/xdg/systemd/user
%ghost %config(noreplace) /etc/X11/xorg.conf.d/00-keyboard.conf
%config(noreplace) /etc/X11/xinit/xinitrc.d/50-systemd-user.sh
%dir /etc/rc.d/init.d
%doc /etc/rc.d/init.d/README
%config(noreplace) /etc/systemd/system.conf
%config(noreplace) /etc/systemd/user.conf
%config(noreplace) /etc/systemd/logind.conf
%config(noreplace) /etc/systemd/journald.conf
%config(noreplace) /etc/systemd/oomd.conf
%dir /etc/systemd/system
%dir /etc/systemd/user
%dir /etc/systemd/network
/usr/sbin/init
/usr/sbin/halt
/usr/sbin/poweroff
/usr/sbin/reboot
/usr/sbin/shutdown
/usr/sbin/runlevel
/usr/sbin/telinit
/usr/bin/systemd-analyze
/usr/bin/systemd-cat
/usr/bin/journalctl
/usr/bin/systemd-dissect
/usr/bin/resolvectl
/usr/bin/loginctl
/usr/bin/systemd-inhibit
/usr/bin/systemd-socket-activate
/usr/bin/systemctl
/usr/bin/portablectl
/usr/bin/systemd-sysext
/usr/bin/userdbctl
/usr/bin/homectl
/usr/bin/hostnamectl
/usr/bin/localectl
/usr/bin/timedatectl
/usr/bin/oomctl
/usr/bin/systemd-firstboot
/usr/bin/systemd-machine-id-setup
/usr/bin/systemd-detect-virt
/usr/bin/systemd-delta
/usr/bin/systemd-escape
/usr/bin/systemd-notify
/usr/bin/systemd-creds
/usr/bin/systemd-id128
/usr/bin/systemd-path
/usr/bin/systemd-ask-password
/usr/bin/systemd-tty-ask-password-agent
/usr/bin/systemd-cgls
/usr/bin/systemd-cgtop
/usr/bin/systemd-mount
/usr/bin/systemd-run
/usr/bin/systemd-stdio-bridge
/usr/bin/busctl
/usr/bin/systemd-sysusers
/usr/bin/systemd-tmpfiles
/usr/bin/systemd-umount
%dir /usr/lib64/systemd
/usr/lib64/systemd/libsystemd-shared-%{version}-%{release}.so
/usr/lib64/systemd/libsystemd-core-%{version}-%{release}.so
%dir /usr/share/factory
%dir /usr/share/systemd
/usr/share/systemd/kbd-model-map
/usr/share/systemd/language-fallback-map
%dir /usr/share/dbus-1/interfaces
/usr/share/dbus-1/services/org.freedesktop.systemd1.service
/usr/share/dbus-1/system-services/org.freedesktop.systemd1.service
/usr/share/dbus-1/system-services/org.freedesktop.hostname1.service
/usr/share/dbus-1/system-services/org.freedesktop.locale1.service
/usr/share/dbus-1/system-services/org.freedesktop.login1.service
/usr/share/dbus-1/system-services/org.freedesktop.oom1.service
/usr/share/dbus-1/system-services/org.freedesktop.timedate1.service
/usr/share/dbus-1/system.d/org.freedesktop.systemd1.conf
/usr/share/dbus-1/system.d/org.freedesktop.hostname1.conf
/usr/share/dbus-1/system.d/org.freedesktop.locale1.conf
/usr/share/dbus-1/system.d/org.freedesktop.login1.conf
/usr/share/dbus-1/system.d/org.freedesktop.oom1.conf
/usr/share/dbus-1/system.d/org.freedesktop.timedate1.conf
/usr/share/dbus-1/interfaces/org.freedesktop.systemd1.Manager.xml
/usr/share/dbus-1/interfaces/org.freedesktop.systemd1.Job.xml
/usr/share/dbus-1/interfaces/org.freedesktop.systemd1.Unit.xml
/usr/share/dbus-1/interfaces/org.freedesktop.systemd1.Automount.xml
/usr/share/dbus-1/interfaces/org.freedesktop.systemd1.Device.xml
/usr/share/dbus-1/interfaces/org.freedesktop.systemd1.Mount.xml
/usr/share/dbus-1/interfaces/org.freedesktop.systemd1.Path.xml
/usr/share/dbus-1/interfaces/org.freedesktop.systemd1.Scope.xml
/usr/share/dbus-1/interfaces/org.freedesktop.systemd1.Service.xml
/usr/share/dbus-1/interfaces/org.freedesktop.systemd1.Slice.xml
/usr/share/dbus-1/interfaces/org.freedesktop.systemd1.Socket.xml
/usr/share/dbus-1/interfaces/org.freedesktop.systemd1.Swap.xml
/usr/share/dbus-1/interfaces/org.freedesktop.systemd1.Target.xml
/usr/share/dbus-1/interfaces/org.freedesktop.systemd1.Timer.xml
/usr/share/dbus-1/interfaces/org.freedesktop.LogControl1.xml
/usr/share/dbus-1/interfaces/org.freedesktop.login1.Manager.xml
/usr/share/dbus-1/interfaces/org.freedesktop.login1.Seat.xml
/usr/share/dbus-1/interfaces/org.freedesktop.login1.Session.xml
/usr/share/dbus-1/interfaces/org.freedesktop.login1.User.xml
/usr/share/dbus-1/interfaces/org.freedesktop.hostname1.xml
/usr/share/dbus-1/interfaces/org.freedesktop.locale1.xml
/usr/share/dbus-1/interfaces/org.freedesktop.timedate1.xml
/usr/share/dbus-1/interfaces/org.freedesktop.oom1.Manager.xml
/usr/share/zsh/site-functions/_systemctl
/usr/share/zsh/site-functions/_busctl
/usr/share/zsh/site-functions/_journalctl
/usr/share/zsh/site-functions/_systemd-analyze
/usr/share/zsh/site-functions/_systemd-delta
/usr/share/zsh/site-functions/_systemd
/usr/share/zsh/site-functions/_systemd-path
/usr/share/zsh/site-functions/_systemd-run
/usr/share/zsh/site-functions/_sd_hosts_or_user_at_host
/usr/share/zsh/site-functions/_sd_outputmodes
/usr/share/zsh/site-functions/_sd_unit_files
/usr/share/zsh/site-functions/_sd_machines
/usr/share/zsh/site-functions/_hostnamectl
/usr/share/zsh/site-functions/_localectl
/usr/share/zsh/site-functions/_loginctl
/usr/share/zsh/site-functions/_oomctl
/usr/share/zsh/site-functions/_systemd-inhibit
/usr/share/zsh/site-functions/_resolvectl
/usr/share/zsh/site-functions/_systemd-tmpfiles
/usr/share/zsh/site-functions/_timedatectl
/usr/share/bash-completion/completions/systemctl
/usr/share/bash-completion/completions/busctl
/usr/share/bash-completion/completions/journalctl
/usr/share/bash-completion/completions/systemd-analyze
/usr/share/bash-completion/completions/systemd-cat
/usr/share/bash-completion/completions/systemd-cgls
/usr/share/bash-completion/completions/systemd-cgtop
/usr/share/bash-completion/completions/systemd-delta
/usr/share/bash-completion/completions/systemd-detect-virt
/usr/share/bash-completion/completions/systemd-id128
/usr/share/bash-completion/completions/systemd-path
/usr/share/bash-completion/completions/systemd-run
/usr/share/bash-completion/completions/homectl
/usr/share/bash-completion/completions/hostnamectl
/usr/share/bash-completion/completions/localectl
/usr/share/bash-completion/completions/loginctl
/usr/share/bash-completion/completions/oomctl
/usr/share/bash-completion/completions/portablectl
/usr/share/bash-completion/completions/resolvectl
/usr/share/bash-completion/completions/timedatectl
/usr/share/man/man8/halt.8*
/usr/share/man/man8/poweroff.8*
/usr/share/man/man8/reboot.8*
/usr/share/man/man8/nss-myhostname.8*
/usr/share/man/man8/nss-resolve.8*
/usr/share/man/man8/nss-systemd.8*
/usr/share/man/man8/runlevel.8*
/usr/share/man/man8/shutdown.8*
/usr/share/man/man8/systemd-ask-password-console.service.8*
/usr/share/man/man8/systemd-ask-password-console.path.8*
/usr/share/man/man8/systemd-ask-password-wall.path.8*
/usr/share/man/man8/systemd-ask-password-wall.service.8*
/usr/share/man/man8/systemd-boot-check-no-failures.service.8*
/usr/share/man/man8/systemd-boot-check-no-failures.8*
/usr/share/man/man8/systemd-debug-generator.8*
/usr/share/man/man8/systemd-environment-d-generator.8*
/usr/share/man/man8/30-systemd-environment-d-generator.8*
/usr/share/man/man8/systemd-fstab-generator.8*
/usr/share/man/man8/systemd-getty-generator.8*
/usr/share/man/man8/systemd-halt.service.8*
/usr/share/man/man8/systemd-kexec.service.8*
/usr/share/man/man8/systemd-poweroff.service.8*
/usr/share/man/man8/systemd-reboot.service.8*
/usr/share/man/man8/systemd-shutdown.8*
/usr/share/man/man8/systemd-hostnamed.service.8*
/usr/share/man/man8/systemd-hostnamed.8*
/usr/share/man/man8/systemd-initctl.service.8*
/usr/share/man/man8/systemd-initctl.8*
/usr/share/man/man8/systemd-initctl.socket.8*
/usr/share/man/man8/systemd-journald.service.8*
/usr/share/man/man8/systemd-journald.8*
/usr/share/man/man8/systemd-journald-audit.socket.8*
/usr/share/man/man8/systemd-journald-dev-log.socket.8*
/usr/share/man/man8/systemd-journald-varlink@.socket.8*
/usr/share/man/man8/systemd-journald.socket.8*
/usr/share/man/man8/systemd-journald@.service.8*
/usr/share/man/man8/systemd-journald@.socket.8*
/usr/share/man/man8/systemd-localed.service.8*
/usr/share/man/man8/systemd-localed.8*
/usr/share/man/man8/systemd-logind.service.8*
/usr/share/man/man8/systemd-logind.8*
/usr/share/man/man8/systemd-machine-id-commit.service.8*
/usr/share/man/man8/systemd-network-generator.service.8*
/usr/share/man/man8/systemd-network-generator.8*
/usr/share/man/man8/telinit.8*
/usr/share/man/man8/systemd-oomd.service.8*
/usr/share/man/man8/systemd-oomd.8*
/usr/share/man/man8/systemd-rc-local-generator.8*
/usr/share/man/man8/rc-local.service.8*
/usr/share/man/man8/systemd-run-generator.8*
/usr/share/man/man8/systemd-socket-proxyd.8*
/usr/share/man/man8/systemd-sysext.8*
/usr/share/man/man8/systemd-sysext.service.8*
/usr/share/man/man8/systemd-system-update-generator.8*
/usr/share/man/man8/systemd-sysupdate.8*
/usr/share/man/man8/systemd-sysupdate-reboot.service.8*
/usr/share/man/man8/systemd-sysupdate-reboot.timer.8*
/usr/share/man/man8/systemd-sysupdate.service.8*
/usr/share/man/man8/systemd-sysupdate.timer.8*
/usr/share/man/man8/systemd-sysusers.8*
/usr/share/man/man8/systemd-sysusers.service.8*
/usr/share/man/man8/systemd-sysv-generator.8*
/usr/share/man/man8/systemd-time-wait-sync.service.8*
/usr/share/man/man8/systemd-time-wait-sync.8*
/usr/share/man/man8/systemd-timedated.service.8*
/usr/share/man/man8/systemd-timedated.8*
/usr/share/man/man8/systemd-tmpfiles.8*
/usr/share/man/man8/systemd-tmpfiles-clean.service.8*
/usr/share/man/man8/systemd-tmpfiles-clean.timer.8*
/usr/share/man/man8/systemd-tmpfiles-setup.service.8*
/usr/share/man/man8/systemd-update-done.service.8*
/usr/share/man/man8/systemd-update-done.8*
/usr/share/man/man8/systemd-update-utmp.service.8*
/usr/share/man/man8/systemd-update-utmp.8*
/usr/share/man/man8/systemd-update-utmp-runlevel.service.8*
/usr/share/man/man8/systemd-user-sessions.service.8*
/usr/share/man/man8/systemd-user-sessions.8*
/usr/share/man/man8/systemd-userdbd.service.8*
/usr/share/man/man8/systemd-userdbd.8*
/usr/share/man/man8/systemd-xdg-autostart-generator.8*
/usr/share/man/man7/bootup.7*
/usr/share/man/man7/daemon.7*
/usr/share/man/man7/file-hierarchy.7*
/usr/share/man/man7/kernel-command-line.7*
/usr/share/man/man7/systemd-stub.7*
/usr/share/man/man7/linuxaa64.efi.stub.7*
/usr/share/man/man7/linuxia32.efi.stub.7*
/usr/share/man/man7/linuxx64.efi.stub.7*
/usr/share/man/man7/sd-stub.7*
/usr/share/man/man7/systemd.environment-generator.7*
/usr/share/man/man7/systemd.generator.7*
/usr/share/man/man7/systemd.journal-fields.7*
/usr/share/man/man7/systemd.net-naming-scheme.7*
/usr/share/man/man7/systemd.offline-updates.7*
/usr/share/man/man7/systemd.special.7*
/usr/share/man/man7/systemd.syntax.7*
/usr/share/man/man7/systemd.system-credentials.7*
/usr/share/man/man7/systemd.time.7*
/usr/share/man/man7/systemd.directives.7*
/usr/share/man/man7/systemd.index.7*
/usr/share/man/man1/busctl.1*
/usr/share/man/man1/homectl.1*
/usr/share/man/man1/hostnamectl.1*
/usr/share/man/man1/journalctl.1*
/usr/share/man/man1/localectl.1*
/usr/share/man/man1/loginctl.1*
/usr/share/man/man1/oomctl.1*
/usr/share/man/man1/portablectl.1*
/usr/share/man/man1/resolvectl.1*
/usr/share/man/man1/systemctl.1*
/usr/share/man/man1/systemd-analyze.1*
/usr/share/man/man1/systemd-ask-password.1*
/usr/share/man/man1/systemd-cat.1*
/usr/share/man/man1/systemd-cgls.1*
/usr/share/man/man1/systemd-cgtop.1*
/usr/share/man/man1/systemd-creds.1*
/usr/share/man/man1/systemd-delta.1*
/usr/share/man/man1/systemd-detect-virt.1*
/usr/share/man/man1/systemd-dissect.1*
/usr/share/man/man1/systemd-escape.1*
/usr/share/man/man1/systemd-firstboot.1*
/usr/share/man/man1/systemd-firstboot.service.1*
/usr/share/man/man1/systemd-id128.1*
/usr/share/man/man1/systemd-inhibit.1*
/usr/share/man/man1/systemd-machine-id-setup.1*
/usr/share/man/man1/systemd-mount.1*
/usr/share/man/man1/systemd-umount.1*
/usr/share/man/man1/systemd-notify.1*
/usr/share/man/man1/systemd-path.1*
/usr/share/man/man1/systemd-run.1*
/usr/share/man/man1/systemd-socket-activate.1*
/usr/share/man/man1/systemd-stdio-bridge.1*
/usr/share/man/man1/systemd-tty-ask-password-agent.1*
/usr/share/man/man1/systemd.1*
/usr/share/man/man1/init.1*
/usr/share/man/man1/timedatectl.1*
/usr/share/man/man1/userdbctl.1*
/usr/share/man/man5/dnssec-trust-anchors.d.5*
/usr/share/man/man5/environment.d.5*
/usr/share/man/man5/hostname.5*
/usr/share/man/man5/journald.conf.5*
/usr/share/man/man5/journald.conf.d.5*
/usr/share/man/man5/journald@.conf.5*
/usr/share/man/man5/locale.conf.5*
/usr/share/man/man5/localtime.5*
/usr/share/man/man5/logind.conf.5*
/usr/share/man/man5/logind.conf.d.5*
/usr/share/man/man5/machine-id.5*
/usr/share/man/man5/machine-info.5*
/usr/share/man/man5/oomd.conf.5*
/usr/share/man/man5/oomd.conf.d.5*
/usr/share/man/man5/org.freedesktop.LogControl1.5*
/usr/share/man/man5/org.freedesktop.hostname1.5*
/usr/share/man/man5/org.freedesktop.locale1.5*
/usr/share/man/man5/org.freedesktop.login1.5*
/usr/share/man/man5/org.freedesktop.oom1.5*
/usr/share/man/man5/org.freedesktop.systemd1.5*
/usr/share/man/man5/org.freedesktop.timedate1.5*
/usr/share/man/man5/os-release.5*
/usr/share/man/man5/extension-release.5*
/usr/share/man/man5/systemd-system.conf.5*
/usr/share/man/man5/system.conf.d.5*
/usr/share/man/man5/systemd-user.conf.5*
/usr/share/man/man5/user.conf.d.5*
/usr/share/man/man5/systemd.automount.5*
/usr/share/man/man5/systemd.device.5*
/usr/share/man/man5/systemd.dnssd.5*
/usr/share/man/man5/systemd.exec.5*
/usr/share/man/man5/systemd.kill.5*
/usr/share/man/man5/systemd.link.5*
/usr/share/man/man5/systemd.mount.5*
/usr/share/man/man5/systemd.nspawn.5*
/usr/share/man/man5/systemd.path.5*
/usr/share/man/man5/systemd.preset.5*
/usr/share/man/man5/systemd.resource-control.5*
/usr/share/man/man5/systemd.scope.5*
/usr/share/man/man5/systemd.service.5*
/usr/share/man/man5/systemd.slice.5*
/usr/share/man/man5/systemd.socket.5*
/usr/share/man/man5/systemd.swap.5*
/usr/share/man/man5/systemd.target.5*
/usr/share/man/man5/systemd.timer.5*
/usr/share/man/man5/systemd.unit.5*
/usr/share/man/man5/sysupdate.d.5*
/usr/share/man/man5/sysusers.d.5*
/usr/share/man/man5/tmpfiles.d.5*
/usr/share/man/man5/user@.service.5*
/usr/share/man/man5/systemd-user-runtime-dir.5*
/usr/share/man/man5/user-runtime-dir@.service.5*
/usr/share/man/man5/veritytab.5*
/usr/share/polkit-1/actions/org.freedesktop.systemd1.policy
/usr/share/polkit-1/actions/org.freedesktop.hostname1.policy
/usr/share/polkit-1/actions/org.freedesktop.locale1.policy
/usr/share/polkit-1/actions/org.freedesktop.login1.policy
/usr/share/polkit-1/actions/org.freedesktop.timedate1.policy
/usr/share/pkgconfig/udev.pc
/usr/share/pkgconfig/systemd.pc
%dir /usr/share/factory/etc
%dir /usr/share/factory/etc/pam.d
/usr/share/factory/etc/issue
/usr/share/factory/etc/nsswitch.conf
/usr/share/factory/etc/locale.conf
/usr/share/factory/etc/pam.d/other
/usr/share/factory/etc/pam.d/system-auth
%dir /usr/lib/systemd
%dir /usr/lib/pam.d
%dir /usr/lib/sysusers.d
%dir /usr/lib/tmpfiles.d
%dir /usr/lib/environment.d
/usr/lib/environment.d/99-environment.conf
/usr/lib/tmpfiles.d/etc.conf
/usr/lib/tmpfiles.d/legacy.conf
/usr/lib/tmpfiles.d/static-nodes-permissions.conf
/usr/lib/tmpfiles.d/systemd.conf
/usr/lib/tmpfiles.d/var.conf
%doc /usr/lib/tmpfiles.d/README
/usr/lib/tmpfiles.d/home.conf
/usr/lib/tmpfiles.d/journal-nocow.conf
/usr/lib/tmpfiles.d/portables.conf
/usr/lib/tmpfiles.d/systemd-nologin.conf
/usr/lib/tmpfiles.d/systemd-tmp.conf
/usr/lib/tmpfiles.d/tmp.conf
/usr/lib/tmpfiles.d/x11.conf
/usr/lib/tmpfiles.d/provision.conf
/usr/lib/sysusers.d/basic.conf
/usr/lib/sysusers.d/systemd-journal.conf
%doc /usr/lib/sysusers.d/README
/usr/lib/sysusers.d/systemd-oom.conf
/usr/lib/pam.d/systemd-user
%dir /usr/lib/systemd/catalog
/usr/lib/systemd/systemd-update-helper
/usr/lib/systemd/systemd
/usr/lib/systemd/systemd-journald
%dir /usr/lib/systemd/system-generators
%dir /usr/lib/systemd/user-environment-generators
/usr/lib/systemd/systemd-logind
/usr/lib/systemd/systemd-user-runtime-dir
/usr/lib/systemd/systemd-user-sessions
/usr/lib/systemd/systemd-boot-check-no-failures
/usr/lib/systemd/systemd-userwork
/usr/lib/systemd/systemd-userdbd
/usr/lib/systemd/systemd-homework
%dir /usr/lib/systemd/user-generators
/usr/lib/systemd/systemd-xdg-autostart-condition
/usr/lib/systemd/systemd-hostnamed
/usr/lib/systemd/systemd-localed
/usr/lib/systemd/systemd-timedated
/usr/lib/systemd/systemd-time-wait-sync
/usr/lib/systemd/systemd-export
/usr/lib/systemd/systemd-oomd
/usr/lib/systemd/systemd-sysupdate
/usr/lib/systemd/systemd-ac-power
/usr/lib/systemd/systemd-cgroups-agent
/usr/lib/systemd/systemd-reply-password
/usr/lib/systemd/systemd-initctl
/usr/lib/systemd/systemd-socket-proxyd
/usr/lib/systemd/systemd-shutdown
/usr/lib/systemd/systemd-update-done
/usr/lib/systemd/systemd-update-utmp
/usr/lib/systemd/systemd-network-generator
/usr/lib/systemd/systemd-sulogin-shell
%dir /usr/lib/systemd/system
%dir /usr/lib/systemd/portable
/usr/lib/systemd/resolv.conf
%dir /usr/lib/systemd/ntp-units.d
%dir /usr/lib/systemd/user
%dir /usr/lib/systemd/system-preset
%dir /usr/lib/systemd/user-preset
%dir /usr/lib/systemd/network
%dir /usr/lib/systemd/system-shutdown
/usr/lib/systemd/systemd-sysroot-fstab-check
/usr/lib/systemd/libsystemd-shared.abignore
/usr/lib/systemd/purge-nobody-user
/usr/lib/systemd/user-preset/90-systemd.preset
/usr/lib/systemd/system-preset/90-systemd.preset
/usr/lib/systemd/user/app.slice
/usr/lib/systemd/user/background.slice
/usr/lib/systemd/user/basic.target
/usr/lib/systemd/user/bluetooth.target
/usr/lib/systemd/user/default.target
/usr/lib/systemd/user/exit.target
/usr/lib/systemd/user/graphical-session-pre.target
/usr/lib/systemd/user/graphical-session.target
/usr/lib/systemd/user/paths.target
/usr/lib/systemd/user/printer.target
/usr/lib/systemd/user/session.slice
/usr/lib/systemd/user/shutdown.target
/usr/lib/systemd/user/smartcard.target
/usr/lib/systemd/user/sockets.target
/usr/lib/systemd/user/sound.target
/usr/lib/systemd/user/systemd-exit.service
/usr/lib/systemd/user/systemd-tmpfiles-clean.service
/usr/lib/systemd/user/systemd-tmpfiles-clean.timer
/usr/lib/systemd/user/systemd-tmpfiles-setup.service
/usr/lib/systemd/user/timers.target
/usr/lib/systemd/user/xdg-desktop-autostart.target
%dir /usr/lib/systemd/user/slice.d
%dir /usr/lib/systemd/portable/profile
%dir /usr/lib/systemd/portable/profile/default
%dir /usr/lib/systemd/portable/profile/nonetwork
%dir /usr/lib/systemd/portable/profile/strict
%dir /usr/lib/systemd/portable/profile/trusted
/usr/lib/systemd/portable/profile/trusted/service.conf
/usr/lib/systemd/portable/profile/strict/service.conf
/usr/lib/systemd/portable/profile/nonetwork/service.conf
/usr/lib/systemd/portable/profile/default/service.conf
/usr/lib/systemd/system/console-getty.service
/usr/lib/systemd/system/container-getty@.service
/usr/lib/systemd/system/debug-shell.service
/usr/lib/systemd/system/emergency.service
/usr/lib/systemd/system/getty@.service
/usr/lib/systemd/system/rc-local.service
/usr/lib/systemd/system/rescue.service
/usr/lib/systemd/system/serial-getty@.service
/usr/lib/systemd/system/systemd-boot-check-no-failures.service
/usr/lib/systemd/system/systemd-hostnamed.service
/usr/lib/systemd/system/systemd-initctl.service
/usr/lib/systemd/system/systemd-journald.service
/usr/lib/systemd/system/systemd-journald@.service
/usr/lib/systemd/system/systemd-localed.service
/usr/lib/systemd/system/systemd-logind.service
/usr/lib/systemd/system/systemd-network-generator.service
/usr/lib/systemd/system/systemd-oomd.service
/usr/lib/systemd/system/systemd-userdbd.service
/usr/lib/systemd/system/systemd-sysupdate.service
/usr/lib/systemd/system/systemd-sysupdate-reboot.service
/usr/lib/systemd/system/systemd-timedated.service
/usr/lib/systemd/system/systemd-time-wait-sync.service
/usr/lib/systemd/system/systemd-update-done.service
/usr/lib/systemd/system/systemd-update-utmp-runlevel.service
/usr/lib/systemd/system/systemd-update-utmp.service
/usr/lib/systemd/system/systemd-user-sessions.service
/usr/lib/systemd/system/user-runtime-dir@.service
/usr/lib/systemd/system/user@.service
/usr/lib/systemd/system/basic.target
/usr/lib/systemd/system/blockdev@.target
/usr/lib/systemd/system/bluetooth.target
/usr/lib/systemd/system/boot-complete.target
/usr/lib/systemd/system/dev-hugepages.mount
/usr/lib/systemd/system/dev-mqueue.mount
/usr/lib/systemd/system/emergency.target
/usr/lib/systemd/system/exit.target
/usr/lib/systemd/system/factory-reset.target
/usr/lib/systemd/system/final.target
/usr/lib/systemd/system/first-boot-complete.target
/usr/lib/systemd/system/getty.target
/usr/lib/systemd/system/getty-pre.target
/usr/lib/systemd/system/graphical.target
/usr/lib/systemd/system/halt.target
/usr/lib/systemd/system/kexec.target
/usr/lib/systemd/system/ldconfig.service
/usr/lib/systemd/system/local-fs-pre.target
/usr/lib/systemd/system/local-fs.target
/usr/lib/systemd/system/modprobe@.service
/usr/lib/systemd/system/multi-user.target
/usr/lib/systemd/system/network-online.target
/usr/lib/systemd/system/network-pre.target
/usr/lib/systemd/system/network.target
/usr/lib/systemd/system/nss-lookup.target
/usr/lib/systemd/system/nss-user-lookup.target
/usr/lib/systemd/system/paths.target
/usr/lib/systemd/system/poweroff.target
/usr/lib/systemd/system/printer.target
/usr/lib/systemd/system/reboot.target
/usr/lib/systemd/system/remote-fs-pre.target
/usr/lib/systemd/system/remote-fs.target
/usr/lib/systemd/system/rescue.target
/usr/lib/systemd/system/rpcbind.target
/usr/lib/systemd/system/shutdown.target
/usr/lib/systemd/system/sigpwr.target
/usr/lib/systemd/system/slices.target
/usr/lib/systemd/system/smartcard.target
/usr/lib/systemd/system/sockets.target
/usr/lib/systemd/system/sound.target
/usr/lib/systemd/system/swap.target
/usr/lib/systemd/system/sys-fs-fuse-connections.mount
/usr/lib/systemd/system/sys-kernel-config.mount
/usr/lib/systemd/system/sys-kernel-debug.mount
/usr/lib/systemd/system/sys-kernel-tracing.mount
/usr/lib/systemd/system/sysinit.target
/usr/lib/systemd/system/syslog.socket
/usr/lib/systemd/system/system-update.target
/usr/lib/systemd/system/system-update-pre.target
/usr/lib/systemd/system/system-update-cleanup.service
/usr/lib/systemd/system/systemd-ask-password-console.path
/usr/lib/systemd/system/systemd-ask-password-console.service
/usr/lib/systemd/system/systemd-ask-password-wall.path
/usr/lib/systemd/system/systemd-ask-password-wall.service
/usr/lib/systemd/system/systemd-exit.service
/usr/lib/systemd/system/systemd-firstboot.service
/usr/lib/systemd/system/systemd-halt.service
/usr/lib/systemd/system/systemd-initctl.socket
/usr/lib/systemd/system/systemd-journal-catalog-update.service
/usr/lib/systemd/system/systemd-journal-flush.service
/usr/lib/systemd/system/systemd-journald-audit.socket
/usr/lib/systemd/system/systemd-journald-dev-log.socket
/usr/lib/systemd/system/systemd-journald.socket
/usr/lib/systemd/system/systemd-kexec.service
/usr/lib/systemd/system/systemd-machine-id-commit.service
/usr/lib/systemd/system/systemd-journald@.socket
/usr/lib/systemd/system/systemd-journald-varlink@.socket
/usr/lib/systemd/system/systemd-poweroff.service
/usr/lib/systemd/system/systemd-reboot.service
/usr/lib/systemd/system/systemd-sysext.service
/usr/lib/systemd/system/systemd-sysupdate.timer
/usr/lib/systemd/system/systemd-sysupdate-reboot.timer
/usr/lib/systemd/system/systemd-sysusers.service
/usr/lib/systemd/system/systemd-tmpfiles-clean.service
/usr/lib/systemd/system/systemd-tmpfiles-clean.timer
/usr/lib/systemd/system/systemd-tmpfiles-setup.service
/usr/lib/systemd/system/systemd-userdbd.socket
/usr/lib/systemd/system/time-set.target
/usr/lib/systemd/system/time-sync.target
/usr/lib/systemd/system/timers.target
/usr/lib/systemd/system/tmp.mount
/usr/lib/systemd/system/umount.target
/usr/lib/systemd/system/usb-gadget.target
/usr/lib/systemd/system/user.slice
/usr/lib/systemd/system/systemd-oomd.socket
%dir /usr/lib/systemd/system/user-.slice.d
%dir /usr/lib/systemd/system/user@.service.d
%dir /usr/lib/systemd/system/user@0.service.d
/usr/lib/systemd/system/autovt@.service
%dir /usr/lib/systemd/system/sysinit.target.wants
/usr/lib/systemd/system/dbus-org.freedesktop.hostname1.service
/usr/lib/systemd/system/dbus-org.freedesktop.locale1.service
%dir /usr/lib/systemd/system/multi-user.target.wants
/usr/lib/systemd/system/dbus-org.freedesktop.login1.service
/usr/lib/systemd/system/dbus-org.freedesktop.timedate1.service
%dir /usr/lib/systemd/system/graphical.target.wants
%dir /usr/lib/systemd/system/rescue.target.wants
/usr/lib/systemd/system/default.target
/usr/lib/systemd/system/runlevel5.target
/usr/lib/systemd/system/runlevel2.target
/usr/lib/systemd/system/runlevel3.target
/usr/lib/systemd/system/runlevel4.target
/usr/lib/systemd/system/runlevel0.target
/usr/lib/systemd/system/ctrl-alt-del.target
/usr/lib/systemd/system/runlevel6.target
/usr/lib/systemd/system/runlevel1.target
%dir /usr/lib/systemd/system/sockets.target.wants
%dir /usr/lib/systemd/system/timers.target.wants
%dir /usr/lib/systemd/system/local-fs.target.wants
%dir /usr/lib/systemd/system/remote-fs.target.wants
%dir /usr/lib/systemd/system/runlevel1.target.wants
%dir /usr/lib/systemd/system/runlevel2.target.wants
%dir /usr/lib/systemd/system/runlevel3.target.wants
%dir /usr/lib/systemd/system/runlevel4.target.wants
%dir /usr/lib/systemd/system/runlevel5.target.wants
%dir /usr/lib/systemd/system/basic.target.wants
%dir /usr/lib/systemd/system/default.target.wants
%dir /usr/lib/systemd/system/dbus.target.wants
%dir /usr/lib/systemd/system/syslog.target.wants
%dir /usr/lib/systemd/system/system.slice.d
/usr/lib/systemd/system/local-fs.target.wants/tmp.mount
/usr/lib/systemd/system/timers.target.wants/systemd-tmpfiles-clean.timer
/usr/lib/systemd/system/sockets.target.wants/systemd-initctl.socket
/usr/lib/systemd/system/sockets.target.wants/systemd-journald-audit.socket
/usr/lib/systemd/system/sockets.target.wants/systemd-journald-dev-log.socket
/usr/lib/systemd/system/sockets.target.wants/systemd-journald.socket
/usr/lib/systemd/system/rescue.target.wants/systemd-update-utmp-runlevel.service
/usr/lib/systemd/system/graphical.target.wants/systemd-update-utmp-runlevel.service
/usr/lib/systemd/system/multi-user.target.wants/systemd-logind.service
/usr/lib/systemd/system/multi-user.target.wants/systemd-update-utmp-runlevel.service
/usr/lib/systemd/system/multi-user.target.wants/systemd-user-sessions.service
/usr/lib/systemd/system/multi-user.target.wants/getty.target
/usr/lib/systemd/system/multi-user.target.wants/systemd-ask-password-wall.path
/usr/lib/systemd/system/sysinit.target.wants/systemd-journald.service
/usr/lib/systemd/system/sysinit.target.wants/systemd-update-done.service
/usr/lib/systemd/system/sysinit.target.wants/systemd-update-utmp.service
/usr/lib/systemd/system/sysinit.target.wants/dev-hugepages.mount
/usr/lib/systemd/system/sysinit.target.wants/dev-mqueue.mount
/usr/lib/systemd/system/sysinit.target.wants/ldconfig.service
/usr/lib/systemd/system/sysinit.target.wants/sys-fs-fuse-connections.mount
/usr/lib/systemd/system/sysinit.target.wants/sys-kernel-config.mount
/usr/lib/systemd/system/sysinit.target.wants/sys-kernel-debug.mount
/usr/lib/systemd/system/sysinit.target.wants/sys-kernel-tracing.mount
/usr/lib/systemd/system/sysinit.target.wants/systemd-ask-password-console.path
/usr/lib/systemd/system/sysinit.target.wants/systemd-firstboot.service
/usr/lib/systemd/system/sysinit.target.wants/systemd-journal-catalog-update.service
/usr/lib/systemd/system/sysinit.target.wants/systemd-journal-flush.service
/usr/lib/systemd/system/sysinit.target.wants/systemd-machine-id-commit.service
/usr/lib/systemd/system/sysinit.target.wants/systemd-sysusers.service
/usr/lib/systemd/system/sysinit.target.wants/systemd-tmpfiles-setup.service
/usr/lib/systemd/system/user@0.service.d/10-login-barrier.conf
/usr/lib/systemd/system/user@.service.d/10-login-barrier.conf
/usr/lib/systemd/system/user-.slice.d/10-defaults.conf
/usr/lib/systemd/user-generators/systemd-xdg-autostart-generator
/usr/lib/systemd/user-environment-generators/30-systemd-environment-d-generator
/usr/lib/systemd/system-generators/systemd-getty-generator
/usr/lib/systemd/system-generators/systemd-debug-generator
/usr/lib/systemd/system-generators/systemd-run-generator
/usr/lib/systemd/system-generators/systemd-fstab-generator
/usr/lib/systemd/system-generators/systemd-system-update-generator
/usr/lib/systemd/system-generators/systemd-sysv-generator
/usr/lib/systemd/system-generators/systemd-rc-local-generator
/usr/lib/systemd/catalog/systemd.bg.catalog
/usr/lib/systemd/catalog/systemd.be.catalog
/usr/lib/systemd/catalog/systemd.be@latin.catalog
/usr/lib/systemd/catalog/systemd.de.catalog
/usr/lib/systemd/catalog/systemd.fr.catalog
/usr/lib/systemd/catalog/systemd.it.catalog
/usr/lib/systemd/catalog/systemd.pl.catalog
/usr/lib/systemd/catalog/systemd.pt_BR.catalog
/usr/lib/systemd/catalog/systemd.ru.catalog
/usr/lib/systemd/catalog/systemd.zh_CN.catalog
/usr/lib/systemd/catalog/systemd.zh_TW.catalog
/usr/lib/systemd/catalog/systemd.catalog
%license LICENSE.GPL2 LICENSE.LGPL2.1
%license LICENSES/MIT.txt
%ghost %dir %attr(0755,-,-) %{systemd_etc_dir}/basic.target.wants
%ghost %dir %attr(0755,-,-) %{systemd_etc_dir}/bluetooth.target.wants
%ghost %dir %attr(0755,-,-) %{systemd_etc_dir}/default.target.wants
%ghost %dir %attr(0755,-,-) %{systemd_etc_dir}/getty.target.wants
%ghost %dir %attr(0755,-,-) %{systemd_etc_dir}/graphical.target.wants
%ghost %dir %attr(0755,-,-) %{systemd_etc_dir}/local-fs.target.wants
%ghost %dir %attr(0755,-,-) %{systemd_etc_dir}/machines.target.wants
%ghost %dir %attr(0755,-,-) %{systemd_etc_dir}/multi-user.target.wants
%ghost %dir %attr(0755,-,-) %{systemd_etc_dir}/network-online.target.wants
%ghost %dir %attr(0755,-,-) %{systemd_etc_dir}/printer.target.wants
%ghost %dir %attr(0755,-,-) %{systemd_etc_dir}/remote-fs.target.wants
%ghost %dir %attr(0755,-,-) %{systemd_etc_dir}/sockets.target.wants
%ghost %dir %attr(0755,-,-) %{systemd_etc_dir}/sysinit.target.wants
%ghost %dir %attr(0755,-,-) %{systemd_etc_dir}/system-update.target.wants
%ghost %dir %attr(0755,-,-) %{systemd_etc_dir}/timers.target.wants
%ghost %dir %attr(0700,-,-) /var/lib/portables
%ghost %dir %attr(0755,-,-) /var/lib/rpm-state/systemd
%doc %{_pkgdocdir}

%files libs
%license LICENSE.LGPL2.1
/usr/lib64/libsystemd.so.0.35.0
/usr/lib64/libudev.so.1.7.5
/usr/lib64/libnss_myhostname.so.2
/usr/lib64/libnss_systemd.so.2
/usr/lib64/libnss_resolve.so.2
/usr/lib64/libsystemd.so.0
/usr/lib64/libudev.so.1
/usr/share/man/man8/libnss_myhostname.so.2.8*
/usr/share/man/man8/libnss_resolve.so.2.8*
/usr/share/man/man8/libnss_systemd.so.2.8*

%files pam
/usr/lib64/security/pam_systemd.so
/usr/lib64/security/pam_systemd_home.so
/usr/share/man/man8/pam_systemd.8*
/usr/share/man/man8/pam_systemd_home.8*

%files rpm-macros
%dir /usr/lib/rpm/fileattrs
/usr/lib/rpm/sysusers.prov
/usr/lib/rpm/sysusers.generate-pre.sh
/usr/lib/rpm/fileattrs/sysusers.attr
/usr/lib/rpm/macros.d/macros.systemd
/usr/lib/rpm/macros.d/macros.sysusers

%files resolved
%config(noreplace) /etc/systemd/resolved.conf
/usr/sbin/resolvconf
/usr/bin/systemd-resolve
/usr/share/dbus-1/system-services/org.freedesktop.resolve1.service
/usr/share/dbus-1/system.d/org.freedesktop.resolve1.conf
/usr/share/dbus-1/interfaces/org.freedesktop.resolve1.Manager.xml
/usr/share/dbus-1/interfaces/org.freedesktop.resolve1.Link.xml
/usr/share/dbus-1/interfaces/org.freedesktop.resolve1.DnssdService.xml
/usr/share/bash-completion/completions/systemd-resolve
/usr/share/man/man8/systemd-resolved.service.8*
/usr/share/man/man8/systemd-resolved.8*
/usr/share/man/man1/resolvconf.1*
/usr/share/man/man5/systemd.negative.5*
/usr/share/man/man5/systemd.positive.5*
/usr/share/man/man5/org.freedesktop.resolve1.5*
/usr/share/man/man5/resolved.conf.5*
/usr/share/man/man5/resolved.conf.d.5*
/usr/share/polkit-1/actions/org.freedesktop.resolve1.policy
/usr/lib/tmpfiles.d/systemd-resolve.conf
/usr/lib/sysusers.d/systemd-resolve.conf
/usr/lib/systemd/systemd-resolved
/usr/lib/systemd/system/systemd-resolved.service

%files devel -f %{SOURCE32}

%files udev
%ghost %dir /var/lib/systemd/coredump
%ghost %dir /var/lib/systemd/backlight
%ghost %dir /var/lib/systemd/rfkill
%ghost %dir /var/lib/systemd/timesync
%ghost %attr(0600,root,root) /var/lib/systemd/random-seed
%ghost /var/lib/systemd/timesync/clock
%dir /etc/udev
%dir /etc/kernel
%dir /etc/binfmt.d
%dir /etc/modules-load.d
%dir /etc/sysctl.d
%ghost %config(noreplace) /etc/crypttab
%config(noreplace) /etc/sysctl.conf
%ghost %config(noreplace) /etc/vconsole.conf
%config(noreplace) /etc/sysctl.d/99-sysctl.conf
%dir /etc/kernel/install.d
%config(noreplace) /etc/udev/udev.conf
%dir /etc/udev/rules.d
%dir /etc/udev/hwdb.d
%ghost %attr(0444,root,root) /etc/udev/hwdb.bin
%config(noreplace) /etc/systemd/timesyncd.conf
%config(noreplace) /etc/systemd/coredump.conf
%config(noreplace) /etc/systemd/homed.conf
%config(noreplace) /etc/systemd/pstore.conf
%config(noreplace) /etc/systemd/sleep.conf
/usr/sbin/udevadm
/usr/bin/bootctl
/usr/bin/systemd-cryptenroll
/usr/bin/coredumpctl
/usr/bin/systemd-hwdb
/usr/bin/udevadm
/usr/bin/systemd-repart
/usr/bin/kernel-install
%dir /usr/lib64/cryptsetup
/usr/lib64/cryptsetup/libcryptsetup-token-systemd-tpm2.so
/usr/lib64/cryptsetup/libcryptsetup-token-systemd-fido2.so
/usr/lib64/cryptsetup/libcryptsetup-token-systemd-pkcs11.so
/usr/share/dbus-1/system-services/org.freedesktop.home1.service
/usr/share/dbus-1/system-services/org.freedesktop.portable1.service
/usr/share/dbus-1/system-services/org.freedesktop.timesync1.service
/usr/share/dbus-1/system.d/org.freedesktop.home1.conf
/usr/share/dbus-1/system.d/org.freedesktop.portable1.conf
/usr/share/dbus-1/system.d/org.freedesktop.timesync1.conf
/usr/share/dbus-1/interfaces/org.freedesktop.portable1.Manager.xml
/usr/share/dbus-1/interfaces/org.freedesktop.portable1.Image.xml
/usr/share/dbus-1/interfaces/org.freedesktop.home1.Manager.xml
/usr/share/dbus-1/interfaces/org.freedesktop.home1.Home.xml
/usr/share/zsh/site-functions/_udevadm
/usr/share/zsh/site-functions/_kernel-install
/usr/share/zsh/site-functions/_bootctl
/usr/share/zsh/site-functions/_coredumpctl
/usr/share/bash-completion/completions/udevadm
/usr/share/bash-completion/completions/kernel-install
/usr/share/bash-completion/completions/bootctl
/usr/share/bash-completion/completions/coredumpctl
/usr/share/bash-completion/completions/systemd-cryptenroll
/usr/share/man/man8/kernel-install.8*
/usr/share/man/man8/systemd-backlight@.service.8*
/usr/share/man/man8/systemd-backlight.8*
/usr/share/man/man8/systemd-binfmt.service.8*
/usr/share/man/man8/systemd-binfmt.8*
/usr/share/man/man8/systemd-bless-boot-generator.8*
/usr/share/man/man8/systemd-bless-boot.service.8*
/usr/share/man/man8/systemd-bless-boot.8*
/usr/share/man/man8/systemd-boot-system-token.service.8*
/usr/share/man/man8/systemd-coredump.8*
/usr/share/man/man8/systemd-coredump.socket.8*
/usr/share/man/man8/systemd-coredump@.service.8*
/usr/share/man/man8/systemd-cryptsetup-generator.8*
/usr/share/man/man8/systemd-cryptsetup@.service.8*
/usr/share/man/man8/systemd-cryptsetup.8*
/usr/share/man/man8/systemd-fsck@.service.8*
/usr/share/man/man8/systemd-fsck.8*
/usr/share/man/man8/systemd-fsck-root.service.8*
/usr/share/man/man8/systemd-gpt-auto-generator.8*
/usr/share/man/man8/systemd-hibernate-resume-generator.8*
/usr/share/man/man8/systemd-hibernate-resume@.service.8*
/usr/share/man/man8/systemd-hibernate-resume.8*
/usr/share/man/man8/systemd-homed.service.8*
/usr/share/man/man8/systemd-homed.8*
/usr/share/man/man8/systemd-hwdb.8*
/usr/share/man/man8/systemd-integritysetup-generator.8*
/usr/share/man/man8/systemd-integritysetup@.service.8*
/usr/share/man/man8/systemd-integritysetup.8*
/usr/share/man/man8/systemd-makefs@.service.8*
/usr/share/man/man8/systemd-growfs.8*
/usr/share/man/man8/systemd-growfs@.service.8*
/usr/share/man/man8/systemd-makefs.8*
/usr/share/man/man8/systemd-mkswap@.service.8*
/usr/share/man/man8/systemd-modules-load.service.8*
/usr/share/man/man8/systemd-modules-load.8*
/usr/share/man/man8/systemd-pcrphase.service.8*
/usr/share/man/man8/systemd-pcrphase.8*
/usr/share/man/man8/systemd-pcrphase-initrd.service.8*
/usr/share/man/man8/systemd-pcrphase-sysinit.service.8*
/usr/share/man/man8/systemd-portabled.service.8*
/usr/share/man/man8/systemd-portabled.8*
/usr/share/man/man8/systemd-pstore.service.8*
/usr/share/man/man8/systemd-pstore.8*
/usr/share/man/man8/systemd-quotacheck.service.8*
/usr/share/man/man8/systemd-quotacheck.8*
/usr/share/man/man8/systemd-random-seed.service.8*
/usr/share/man/man8/systemd-random-seed.8*
/usr/share/man/man8/systemd-remount-fs.service.8*
/usr/share/man/man8/systemd-remount-fs.8*
/usr/share/man/man8/systemd-repart.8*
/usr/share/man/man8/systemd-repart.service.8*
/usr/share/man/man8/systemd-rfkill.service.8*
/usr/share/man/man8/systemd-rfkill.8*
/usr/share/man/man8/systemd-rfkill.socket.8*
/usr/share/man/man8/systemd-suspend.service.8*
/usr/share/man/man8/systemd-hibernate.service.8*
/usr/share/man/man8/systemd-hybrid-sleep.service.8*
/usr/share/man/man8/systemd-sleep.8*
/usr/share/man/man8/systemd-suspend-then-hibernate.service.8*
/usr/share/man/man8/systemd-sysctl.service.8*
/usr/share/man/man8/systemd-sysctl.8*
/usr/share/man/man8/systemd-timesyncd.service.8*
/usr/share/man/man8/systemd-timesyncd.8*
/usr/share/man/man8/systemd-tmpfiles-setup-dev.service.8*
/usr/share/man/man8/systemd-udev-settle.service.8*
/usr/share/man/man8/systemd-udevd.service.8*
/usr/share/man/man8/systemd-udevd.8*
/usr/share/man/man8/systemd-udevd-control.socket.8*
/usr/share/man/man8/systemd-udevd-kernel.socket.8*
/usr/share/man/man8/systemd-vconsole-setup.service.8*
/usr/share/man/man8/systemd-vconsole-setup.8*
/usr/share/man/man8/systemd-veritysetup-generator.8*
/usr/share/man/man8/systemd-veritysetup@.service.8*
/usr/share/man/man8/systemd-veritysetup.8*
/usr/share/man/man8/systemd-volatile-root.service.8*
/usr/share/man/man8/systemd-volatile-root.8*
/usr/share/man/man8/udevadm.8*
/usr/share/man/man7/hwdb.7*
/usr/share/man/man7/systemd-boot.7*
/usr/share/man/man7/sd-boot.7*
/usr/share/man/man7/udev.7*
/usr/share/man/man1/bootctl.1*
/usr/share/man/man1/coredumpctl.1*
/usr/share/man/man1/systemd-cryptenroll.1*
/usr/share/man/man1/systemd-measure.1*
/usr/share/man/man5/binfmt.d.5*
/usr/share/man/man5/coredump.conf.5*
/usr/share/man/man5/coredump.conf.d.5*
/usr/share/man/man5/crypttab.5*
/usr/share/man/man5/homed.conf.5*
/usr/share/man/man5/homed.conf.d.5*
/usr/share/man/man5/integritytab.5*
/usr/share/man/man5/loader.conf.5*
/usr/share/man/man5/modules-load.d.5*
/usr/share/man/man5/org.freedesktop.home1.5*
/usr/share/man/man5/org.freedesktop.portable1.5*
/usr/share/man/man5/initrd-release.5*
/usr/share/man/man5/pstore.conf.5*
/usr/share/man/man5/pstore.conf.d.5*
/usr/share/man/man5/repart.d.5*
/usr/share/man/man5/sysctl.d.5*
/usr/share/man/man5/systemd-sleep.conf.5*
/usr/share/man/man5/sleep.conf.d.5*
/usr/share/man/man5/timesyncd.conf.5*
/usr/share/man/man5/timesyncd.conf.d.5*
/usr/share/man/man5/udev.conf.5*
/usr/share/man/man5/vconsole.conf.5*
/usr/share/polkit-1/actions/org.freedesktop.home1.policy
/usr/share/polkit-1/actions/org.freedesktop.portable1.policy
/usr/share/polkit-1/actions/org.freedesktop.timesync1.policy
%dir /usr/lib/udev
%dir /usr/lib/sysctl.d
%dir /usr/lib/kernel
%dir /usr/lib/modprobe.d
%dir /usr/lib/binfmt.d
%dir /usr/lib/modules-load.d
%doc /usr/lib/modprobe.d/README
/usr/lib/modprobe.d/systemd.conf
%dir /usr/lib/kernel/install.d
/usr/lib/kernel/install.conf
/usr/lib/kernel/install.d/50-depmod.install
/usr/lib/kernel/install.d/90-loaderentry.install
/usr/lib/tmpfiles.d/systemd-pstore.conf
/usr/lib/sysusers.d/systemd-timesync.conf
/usr/lib/sysusers.d/systemd-coredump.conf
/usr/lib/sysctl.d/50-coredump.conf
%doc /usr/lib/sysctl.d/README
/usr/lib/sysctl.d/50-default.conf
/usr/lib/sysctl.d/50-pid-max.conf
/usr/lib/udev/ata_id
/usr/lib/udev/cdrom_id
/usr/lib/udev/fido_id
/usr/lib/udev/scsi_id
/usr/lib/udev/v4l_id
/usr/lib/udev/mtd_probe
/usr/lib/udev/dmi_memory_id
%dir /usr/lib/udev/rules.d
%dir /usr/lib/udev/hwdb.d
/usr/lib/udev/hwdb.d/60-autosuspend-chromiumos.hwdb
%doc /usr/lib/udev/hwdb.d/README
/usr/lib/udev/hwdb.d/20-dmi-id.hwdb
/usr/lib/udev/hwdb.d/20-pci-vendor-model.hwdb
/usr/lib/udev/hwdb.d/20-pci-classes.hwdb
/usr/lib/udev/hwdb.d/20-usb-vendor-model.hwdb
/usr/lib/udev/hwdb.d/20-usb-classes.hwdb
/usr/lib/udev/hwdb.d/20-sdio-vendor-model.hwdb
/usr/lib/udev/hwdb.d/20-sdio-classes.hwdb
/usr/lib/udev/hwdb.d/20-bluetooth-vendor-product.hwdb
/usr/lib/udev/hwdb.d/20-acpi-vendor.hwdb
/usr/lib/udev/hwdb.d/20-OUI.hwdb
/usr/lib/udev/hwdb.d/20-net-ifname.hwdb
/usr/lib/udev/hwdb.d/20-vmbus-class.hwdb
/usr/lib/udev/hwdb.d/60-autosuspend.hwdb
/usr/lib/udev/hwdb.d/60-autosuspend-fingerprint-reader.hwdb
/usr/lib/udev/hwdb.d/60-evdev.hwdb
/usr/lib/udev/hwdb.d/60-input-id.hwdb
/usr/lib/udev/hwdb.d/60-keyboard.hwdb
/usr/lib/udev/hwdb.d/60-seat.hwdb
/usr/lib/udev/hwdb.d/60-sensor.hwdb
/usr/lib/udev/hwdb.d/70-analyzers.hwdb
/usr/lib/udev/hwdb.d/70-av-production.hwdb
/usr/lib/udev/hwdb.d/70-cameras.hwdb
/usr/lib/udev/hwdb.d/70-joystick.hwdb
/usr/lib/udev/hwdb.d/70-mouse.hwdb
/usr/lib/udev/hwdb.d/70-pda.hwdb
/usr/lib/udev/hwdb.d/70-pointingstick.hwdb
/usr/lib/udev/hwdb.d/70-touchpad.hwdb
/usr/lib/udev/hwdb.d/80-ieee1394-unit-function.hwdb
/usr/lib/udev/rules.d/50-udev-default.rules
/usr/lib/udev/rules.d/64-btrfs.rules
/usr/lib/udev/rules.d/99-systemd.rules
/usr/lib/udev/rules.d/70-uaccess.rules
/usr/lib/udev/rules.d/71-seat.rules
/usr/lib/udev/rules.d/73-seat-late.rules
/usr/lib/udev/rules.d/90-vconsole.rules
%doc /usr/lib/udev/rules.d/README
/usr/lib/udev/rules.d/60-autosuspend.rules
/usr/lib/udev/rules.d/60-block.rules
/usr/lib/udev/rules.d/60-cdrom_id.rules
/usr/lib/udev/rules.d/60-block-scheduler.rules
/usr/lib/udev/rules.d/60-drm.rules
/usr/lib/udev/rules.d/60-evdev.rules
/usr/lib/udev/rules.d/60-fido-id.rules
/usr/lib/udev/rules.d/60-input-id.rules
/usr/lib/udev/rules.d/60-persistent-alsa.rules
/usr/lib/udev/rules.d/60-persistent-input.rules
/usr/lib/udev/rules.d/60-persistent-storage.rules
/usr/lib/udev/rules.d/60-persistent-storage-tape.rules
/usr/lib/udev/rules.d/60-persistent-v4l.rules
/usr/lib/udev/rules.d/60-sensor.rules
/usr/lib/udev/rules.d/60-serial.rules
/usr/lib/udev/rules.d/70-camera.rules
/usr/lib/udev/rules.d/70-joystick.rules
/usr/lib/udev/rules.d/70-mouse.rules
/usr/lib/udev/rules.d/70-touchpad.rules
/usr/lib/udev/rules.d/75-net-description.rules
/usr/lib/udev/rules.d/75-probe_mtd.rules
/usr/lib/udev/rules.d/78-sound-card.rules
/usr/lib/udev/rules.d/80-net-setup-link.rules
/usr/lib/udev/rules.d/81-net-dhcp.rules
/usr/lib/udev/rules.d/80-drivers.rules
/usr/lib/udev/rules.d/70-memory.rules
/usr/lib/udev/rules.d/70-power-switch.rules
%dir /usr/lib/systemd/boot
/usr/lib/systemd/systemd-hibernate-resume
/usr/lib/systemd/systemd-bless-boot
/usr/lib/systemd/systemd-measure
/usr/lib/systemd/systemd-pcrphase
/usr/lib/systemd/systemd-portabled
/usr/lib/systemd/systemd-homed
/usr/lib/systemd/systemd-backlight
/usr/lib/systemd/systemd-rfkill
/usr/lib/systemd/systemd-cryptsetup
/usr/lib/systemd/systemd-veritysetup
/usr/lib/systemd/systemd-integritysetup
/usr/lib/systemd/systemd-timesyncd
/usr/lib/systemd/systemd-coredump
/usr/lib/systemd/systemd-pstore
/usr/lib/systemd/systemd-binfmt
/usr/lib/systemd/systemd-vconsole-setup
/usr/lib/systemd/systemd-random-seed
/usr/lib/systemd/systemd-remount-fs
/usr/lib/systemd/systemd-fsck
/usr/lib/systemd/systemd-growfs
/usr/lib/systemd/systemd-makefs
/usr/lib/systemd/systemd-sleep
/usr/lib/systemd/systemd-sysctl
/usr/lib/systemd/systemd-volatile-root
/usr/lib/systemd/systemd-quotacheck
/usr/lib/systemd/systemd-modules-load
%dir /usr/lib/systemd/system-sleep
/usr/lib/systemd/systemd-udevd
/usr/lib/systemd/network/99-default.link
/usr/lib/systemd/ntp-units.d/80-systemd-timesync.list
/usr/lib/systemd/system/initrd-parse-etc.service
/usr/lib/systemd/system/kmod-static-nodes.service
/usr/lib/systemd/system/quotaon.service
/usr/lib/systemd/system/systemd-backlight@.service
/usr/lib/systemd/system/systemd-binfmt.service
/usr/lib/systemd/system/systemd-bless-boot.service
/usr/lib/systemd/system/systemd-coredump@.service
/usr/lib/systemd/system/systemd-pstore.service
/usr/lib/systemd/system/systemd-fsck-root.service
/usr/lib/systemd/system/systemd-fsck@.service
/usr/lib/systemd/system/systemd-hibernate-resume@.service
/usr/lib/systemd/system/systemd-hibernate.service
/usr/lib/systemd/system/systemd-hybrid-sleep.service
/usr/lib/systemd/system/systemd-suspend-then-hibernate.service
/usr/lib/systemd/system/systemd-hwdb-update.service
/usr/lib/systemd/system/systemd-modules-load.service
/usr/lib/systemd/system/systemd-portabled.service
/usr/lib/systemd/system/systemd-homed.service
/usr/lib/systemd/system/systemd-quotacheck.service
/usr/lib/systemd/system/systemd-random-seed.service
/usr/lib/systemd/system/systemd-remount-fs.service
/usr/lib/systemd/system/systemd-rfkill.service
/usr/lib/systemd/system/systemd-suspend.service
/usr/lib/systemd/system/systemd-sysctl.service
/usr/lib/systemd/system/systemd-timesyncd.service
/usr/lib/systemd/system/systemd-udevd.service
/usr/lib/systemd/system/systemd-vconsole-setup.service
/usr/lib/systemd/system/systemd-volatile-root.service
/usr/lib/systemd/system/systemd-repart.service
/usr/lib/systemd/system/systemd-pcrphase-initrd.service
/usr/lib/systemd/system/systemd-pcrphase-sysinit.service
/usr/lib/systemd/system/systemd-pcrphase.service
/usr/lib/systemd/system/cryptsetup-pre.target
/usr/lib/systemd/system/cryptsetup.target
/usr/lib/systemd/system/veritysetup-pre.target
/usr/lib/systemd/system/veritysetup.target
/usr/lib/systemd/system/integritysetup-pre.target
/usr/lib/systemd/system/integritysetup.target
/usr/lib/systemd/system/hibernate.target
/usr/lib/systemd/system/hybrid-sleep.target
/usr/lib/systemd/system/suspend-then-hibernate.target
/usr/lib/systemd/system/initrd-cleanup.service
/usr/lib/systemd/system/initrd-fs.target
/usr/lib/systemd/system/initrd-root-device.target
/usr/lib/systemd/system/initrd-root-fs.target
/usr/lib/systemd/system/initrd-switch-root.service
/usr/lib/systemd/system/initrd-switch-root.target
/usr/lib/systemd/system/initrd-udevadm-cleanup-db.service
/usr/lib/systemd/system/initrd-usr-fs.target
/usr/lib/systemd/system/initrd.target
/usr/lib/systemd/system/proc-sys-fs-binfmt_misc.automount
/usr/lib/systemd/system/proc-sys-fs-binfmt_misc.mount
/usr/lib/systemd/system/remote-cryptsetup.target
/usr/lib/systemd/system/remote-veritysetup.target
/usr/lib/systemd/system/sleep.target
/usr/lib/systemd/system/suspend.target
/usr/lib/systemd/system/system-systemd\x2dcryptsetup.slice
/usr/lib/systemd/system/systemd-boot-system-token.service
/usr/lib/systemd/system/systemd-boot-update.service
/usr/lib/systemd/system/systemd-coredump.socket
/usr/lib/systemd/system/systemd-homed-activate.service
/usr/lib/systemd/system/systemd-rfkill.socket
/usr/lib/systemd/system/systemd-tmpfiles-setup-dev.service
/usr/lib/systemd/system/systemd-udevd-control.socket
/usr/lib/systemd/system/systemd-udev-settle.service
/usr/lib/systemd/system/systemd-udev-trigger.service
/usr/lib/systemd/system/systemd-udevd-kernel.socket
/usr/lib/systemd/system/dbus-org.freedesktop.portable1.service
%dir /usr/lib/systemd/system/initrd-root-fs.target.wants
%dir /usr/lib/systemd/system/initrd.target.wants
%dir /usr/lib/systemd/system/initrd-root-device.target.wants
%dir /usr/lib/systemd/system/systemd-udev-trigger.service.d
/usr/lib/systemd/system/systemd-udev-trigger.service.d/systemd-udev-trigger-no-reload.conf
/usr/lib/systemd/system/sockets.target.wants/systemd-coredump.socket
/usr/lib/systemd/system/sockets.target.wants/systemd-udevd-control.socket
/usr/lib/systemd/system/sockets.target.wants/systemd-udevd-kernel.socket
/usr/lib/systemd/system/initrd-root-device.target.wants/remote-cryptsetup.target
/usr/lib/systemd/system/initrd-root-device.target.wants/remote-veritysetup.target
/usr/lib/systemd/system/initrd.target.wants/systemd-pcrphase-initrd.service
/usr/lib/systemd/system/initrd-root-fs.target.wants/systemd-repart.service
/usr/lib/systemd/system/sysinit.target.wants/kmod-static-nodes.service
/usr/lib/systemd/system/sysinit.target.wants/systemd-binfmt.service
/usr/lib/systemd/system/sysinit.target.wants/systemd-hwdb-update.service
/usr/lib/systemd/system/sysinit.target.wants/systemd-modules-load.service
/usr/lib/systemd/system/sysinit.target.wants/systemd-random-seed.service
/usr/lib/systemd/system/sysinit.target.wants/systemd-sysctl.service
/usr/lib/systemd/system/sysinit.target.wants/systemd-udevd.service
/usr/lib/systemd/system/sysinit.target.wants/systemd-repart.service
/usr/lib/systemd/system/sysinit.target.wants/systemd-pcrphase-sysinit.service
/usr/lib/systemd/system/sysinit.target.wants/systemd-pcrphase.service
/usr/lib/systemd/system/sysinit.target.wants/cryptsetup.target
/usr/lib/systemd/system/sysinit.target.wants/veritysetup.target
/usr/lib/systemd/system/sysinit.target.wants/integritysetup.target
/usr/lib/systemd/system/sysinit.target.wants/proc-sys-fs-binfmt_misc.automount
/usr/lib/systemd/system/sysinit.target.wants/systemd-boot-system-token.service
/usr/lib/systemd/system/sysinit.target.wants/systemd-tmpfiles-setup-dev.service
/usr/lib/systemd/system/sysinit.target.wants/systemd-udev-trigger.service
/usr/lib/systemd/system-generators/systemd-hibernate-resume-generator
/usr/lib/systemd/system-generators/systemd-gpt-auto-generator
/usr/lib/systemd/system-generators/systemd-bless-boot-generator
/usr/lib/systemd/system-generators/systemd-cryptsetup-generator
/usr/lib/systemd/system-generators/systemd-veritysetup-generator
/usr/lib/systemd/system-generators/systemd-integritysetup-generator


%if %{with gnu_efi}
%files boot-unsigned
%dir /usr/lib/systemd/boot/efi
/usr/lib/systemd/boot/efi/*
%endif

%files container
%ghost %dir %attr(0700,-,-) /var/lib/machines
/usr/bin/machinectl
/usr/bin/systemd-nspawn
/usr/lib64/libnss_mymachines.so.2
/usr/share/dbus-1/system-services/org.freedesktop.import1.service
/usr/share/dbus-1/system-services/org.freedesktop.machine1.service
/usr/share/dbus-1/system.d/org.freedesktop.import1.conf
/usr/share/dbus-1/system.d/org.freedesktop.machine1.conf
/usr/share/dbus-1/interfaces/org.freedesktop.machine1.Manager.xml
/usr/share/dbus-1/interfaces/org.freedesktop.machine1.Machine.xml
/usr/share/dbus-1/interfaces/org.freedesktop.machine1.Image.xml
/usr/share/dbus-1/interfaces/org.freedesktop.import1.Manager.xml
/usr/share/dbus-1/interfaces/org.freedesktop.import1.Transfer.xml
/usr/share/zsh/site-functions/_systemd-nspawn
/usr/share/zsh/site-functions/_machinectl
/usr/share/bash-completion/completions/systemd-nspawn
/usr/share/bash-completion/completions/machinectl
/usr/share/man/man8/nss-mymachines.8*
/usr/share/man/man8/libnss_mymachines.so.2.8*
/usr/share/man/man8/systemd-importd.service.8*
/usr/share/man/man8/systemd-importd.8*
/usr/share/man/man8/systemd-machined.service.8*
/usr/share/man/man8/systemd-machined.8*
/usr/share/man/man1/machinectl.1*
/usr/share/man/man1/systemd-nspawn.1*
/usr/share/man/man5/org.freedesktop.import1.5*
/usr/share/man/man5/org.freedesktop.machine1.5*
/usr/share/polkit-1/actions/org.freedesktop.import1.policy
/usr/share/polkit-1/actions/org.freedesktop.machine1.policy
/usr/lib/tmpfiles.d/systemd-nspawn.conf
/usr/lib/systemd/systemd-machined
/usr/lib/systemd/systemd-importd
/usr/lib/systemd/systemd-pull
/usr/lib/systemd/systemd-import
/usr/lib/systemd/systemd-import-fs
/usr/lib/systemd/import-pubring.gpg
/usr/lib/systemd/system/systemd-importd.service
/usr/lib/systemd/system/systemd-machined.service
/usr/lib/systemd/system/systemd-nspawn@.service
/usr/lib/systemd/system/machine.slice
/usr/lib/systemd/system/machines.target
/usr/lib/systemd/system/var-lib-machines.mount
/usr/lib/systemd/system/dbus-org.freedesktop.import1.service
/usr/lib/systemd/system/dbus-org.freedesktop.machine1.service
%dir /usr/lib/systemd/system/machines.target.wants
/usr/lib/systemd/system/machines.target.wants/var-lib-machines.mount
/usr/lib/systemd/system/remote-fs.target.wants/var-lib-machines.mount


%files journal-remote
%ghost %dir /var/lib/private/systemd/journal-upload
%ghost /var/lib/private/systemd/journal-upload/state
%ghost /var/lib/systemd/journal-upload
%ghost %dir /var/log/journal/remote
%config(noreplace) /etc/systemd/journal-upload.conf
%config(noreplace) /etc/systemd/journal-remote.conf
%dir /usr/share/systemd/gatewayd
/usr/share/systemd/gatewayd/browse.html
/usr/share/man/man8/systemd-journal-gatewayd.service.8*
/usr/share/man/man8/systemd-journal-gatewayd.8*
/usr/share/man/man8/systemd-journal-gatewayd.socket.8*
/usr/share/man/man8/systemd-journal-remote.service.8*
/usr/share/man/man8/systemd-journal-remote.8*
/usr/share/man/man8/systemd-journal-remote.socket.8*
/usr/share/man/man8/systemd-journal-upload.service.8*
/usr/share/man/man8/systemd-journal-upload.8*
/usr/share/man/man5/journal-remote.conf.5*
/usr/share/man/man5/journal-remote.conf.d.5*
/usr/share/man/man5/journal-upload.conf.5*
/usr/share/man/man5/journal-upload.conf.d.5*
/usr/lib/firewalld/services/systemd-journal-remote.xml
/usr/lib/firewalld/services/systemd-journal-gatewayd.xml
/usr/lib/sysusers.d/systemd-remote.conf
/usr/lib/systemd/systemd-journal-upload
/usr/lib/systemd/systemd-journal-remote
/usr/lib/systemd/systemd-journal-gatewayd
/usr/lib/systemd/system/systemd-journal-gatewayd.service
/usr/lib/systemd/system/systemd-journal-remote.service
/usr/lib/systemd/system/systemd-journal-upload.service
/usr/lib/systemd/system/systemd-journal-gatewayd.socket
/usr/lib/systemd/system/systemd-journal-remote.socket

%files networkd
%config(noreplace) /etc/systemd/networkd.conf
/usr/bin/networkctl
/usr/share/dbus-1/system-services/org.freedesktop.network1.service
/usr/share/dbus-1/system.d/org.freedesktop.network1.conf
/usr/share/dbus-1/interfaces/org.freedesktop.network1.Manager.xml
/usr/share/dbus-1/interfaces/org.freedesktop.network1.DHCPServer.xml
/usr/share/dbus-1/interfaces/org.freedesktop.network1.Link.xml
/usr/share/dbus-1/interfaces/org.freedesktop.network1.Network.xml
/usr/share/zsh/site-functions/_networkctl
/usr/share/bash-completion/completions/networkctl
/usr/share/man/man8/systemd-networkd-wait-online.service.8*
/usr/share/man/man8/systemd-networkd-wait-online.8*
/usr/share/man/man8/systemd-networkd-wait-online@.service.8*
/usr/share/man/man8/systemd-networkd.service.8*
/usr/share/man/man8/systemd-networkd.8*
/usr/share/man/man1/networkctl.1*
/usr/share/man/man5/networkd.conf.5*
/usr/share/man/man5/networkd.conf.d.5*
/usr/share/man/man5/org.freedesktop.network1.5*
/usr/share/man/man5/systemd.netdev.5*
/usr/share/man/man5/systemd.network.5*
/usr/share/polkit-1/rules.d/systemd-networkd.rules
/usr/share/polkit-1/actions/org.freedesktop.network1.policy
/usr/lib/tmpfiles.d/systemd-network.conf
/usr/lib/sysusers.d/systemd-network.conf
/usr/lib/systemd/systemd-networkd
/usr/lib/systemd/systemd-networkd-wait-online
/usr/lib/systemd/network/80-6rd-tunnel.network
/usr/lib/systemd/network/80-container-host0.network
/usr/lib/systemd/network/80-container-ve.network
/usr/lib/systemd/network/80-container-vz.network
/usr/lib/systemd/network/80-ethernet.network.example
/usr/lib/systemd/network/80-vm-vt.network
/usr/lib/systemd/network/80-wifi-adhoc.network
/usr/lib/systemd/network/80-wifi-ap.network.example
/usr/lib/systemd/network/80-wifi-station.network.example
/usr/lib/systemd/system/systemd-networkd.service
/usr/lib/systemd/system/systemd-networkd-wait-online.service
/usr/lib/systemd/system/systemd-networkd-wait-online@.service
/usr/lib/systemd/system/systemd-networkd.socket

%files oomd-defaults
%dir /usr/lib/systemd/oomd.conf.d
/usr/lib/systemd/oomd.conf.d/10-oomd-defaults.conf
/usr/lib/systemd/user/slice.d/10-oomd-per-slice-defaults.conf
/usr/lib/systemd/system/system.slice.d/10-oomd-per-slice-defaults.conf
/usr/lib/systemd/system/user-.slice.d/10-oomd-per-slice-defaults.conf

%files tests -f %{SOURCE31}
%files standalone-tmpfiles
/usr/bin/systemd-tmpfiles.standalone

%files standalone-sysusers
/usr/bin/systemd-sysusers.standalone

%files doc
%doc NEWS README README.md TODO
%doc docs/UIDS-GIDS.md
%doc docs/CONTRIBUTING.md docs/RELEASE.md
%doc docs/TRANSIENT-SETTINGS.md docs/TRANSLATORS.md
%doc docs/ENVIRONMENT.md docs/CODING_STYLE.md
%doc docs/DISTRO_PORTING.md docs/HACKING.md

%changelog
* Wed Apr 12 2023 Chunmei Xu <xuchunmei@linux.alibaba.com> - 252.4-6
- optimise spec file

* Mon Mar 27 2023 mgb01105731 <mgb01105731@alibaba-inc.com> - 252.4-5
- Del Specific Fields

* Sat Mar 25 2023 Chunmei Xu <xuchunmei@linux.alibaba.com> - 252.4-4
- remove buildrequires of xen-devel

* Mon Mar 13 2023 Feng Su <sufeng@linux.alibaba.com> - 252.4-3
- Add dependency for devel package: systemd-rpm-macros

* Fri Mar 03 2023 Funda Wang <fundawang@yeah.net> - 252.4-2
- Use aliyun as default ntp server

* Thu Jan 05 2023 happy_orange <songnannan@linux.alibaba.com> - 252.4-1
- update to 252.4

* Fri Mar 25 2022 Chunmei Xu <xuchunmei@linux.alibaba.com> - 250.4-1
- update to 250.4 from stable repo

* Wed Mar 23 2022 Chunmei Xu <xuchunmei@linux.alibaba.com> - 250-2
- disable libfido2

* Thu Mar 03 2022 Chunmei Xu <xuchunmei@linux.alibaba.com> - 250-1
- init from upstream v250
- fix build failed with "found unknown filesystem(s) defined in kernel headers"
